<?php

    namespace CF7EventTracker;

    class AdminError {

        function __construct( $msg, $err_obj=false ) {
            
            $this->cf7_error_output( $msg, $err_obj );

        }

        protected function cf7_error_output( $msg, $err_obj=false ) {

            if( $err_obj !== false )
                $err = $this->cf7_get_errorcodes( $err_obj );

            add_action( 'admin_notices', function() use ( $msg, $err ) {
                $this->cf7_licence_admin_notice__error( $msg, $err );
            });

        }

        protected function cf7_licence_admin_notice__error( $message, $error_codes="" ) {

            $class = 'notice notice-error';
            printf( '<div class="%1$s"><p>%2$s</p>%3$s</div>', esc_attr( $class ), $message, $error_codes ); 

        }

        protected function cf7_get_errorcodes( $error_obj, $arr=false ) {

            $error_codes = "";
            if( $arr )
                $error_codes = array();
            
            foreach( $error_obj->error as $error_wrapper ) {
                foreach( $error_wrapper->error_data as $error ) {
                    if( $arr ) {
                        $error_codes[] = $error->status;
                    }
                    else {
                        if( !empty( $error_codes ) )
                            $error_codes .= ", ";
                        $error_codes .= $error->status;
                    }
                }
            }

            if( !empty( $error_codes ) && !$arr )
                $error_codes = '<p>' . sprintf( 'Error-Codes: %1$s', $error_codes ) . '</p>';
            
            return $error_codes;

        }


        public static function get_error( $type, $custom=null ) {

            if( $type == -1 && !empty( $custom ) ) {

                $msg = $custom;

            }
            else {

                switch( $type ) {
                    case 101:
                        // General Error
                        $msg = sprintf(
                            _x(
                                'Your license for the "CF7 Event Tracker" plugin has expired or failed.<br/>Please check your license in the <a href="%s">plugin settings</a>.',
                                'Message Error',
                                'cf7-event-tracker'
                            ),
                            '/wp-admin/admin.php?page=cf7_events'
                        );
                        break;
                    case 102:
                        // General Error
                        $msg = sprintf(
                            _x(
                                'Your license for the "CF7 Event Tracker" plugin has been activated for your website. Have fun with the <a href="%s">CF7 Event Tracker</a>!',
                                'Message Error',
                                'cf7-event-tracker'
                            ),
                            '/wp-admin/admin.php?page=cf7_events'
                        );
                        break;
                    case 103:
                        // License Expired
                        // ToDo: Source-String must be updated
                        $msg = sprintf(
                            _x(
                                'Your license has been expired.<br/>Please <a href="%s" target="_blank">Purchase another License</a> or Upgrade your existing one with this voucher code for Agency or Premium-Licenses: %s.',
                                'Message Error',
                                'cf7-event-tracker'
                            ),
                            'https://www.codepalm.de/products/cf7-event-tracker-standard',
                            'VOUCHER_CODE'
                        );
                        break;
                    case 104:
                        // License not found
                        $msg = sprintf(
                            _x(
                                'Your license has not been found in database. Please make sure you use the right license or get a new license on <a href="%s">Codepalm</a>.',
                                'Message Error',
                                'cf7-event-tracker'
                            ),
                            'https://www.codepalm.de/products/cf7-event-tracker-standard'
                        );
                        break;
                    case 201:
                        // Server not found or offline
                        $msg = _x(
                            'The update server for the plugin "CF7 Event Tracker" could not be found or is currently offline. Please try it again in a few minutes.',
                            'Message Error',
                            'cf7-event-tracker'
                        );
                        break;
                    case 301:
                        // Update-Class can't be loaded
                        $msg = sprintf( 
                            _x(
                                'Update can\'t be processed, because Script can\'t be loaded. Please contact <a href="mailto:%1$s">%1$s</a> an specify the error-code "301" to get help.',
                                'Message Error',
                                'cf7-event-tracker'
                            ),
                            'support@codepalm.de'
                        );
                        break;
                    case 302:
                        // Save-Class can't be loaded
                        $msg = sprintf( 
                            _x(
                                'Saving can\'t be processed, because Script can\'t be loaded. Please contact <a href="mailto:%1$s">%1$s</a> an specify the error-code "302" to get help.',
                                'Message Error',
                                'cf7-event-tracker'
                            ),
                            'support@codepalm.de'
                        );
                        break;
                    case 303:
                        // Contact Form 7 isn't installed or activated
                        $msg = sprintf(
                            _x(
                                'To use the "CF7 Evet Tracker" plugin, you need Contact Form 7.<br/>Install it via the <a href="%1$s">plugin page</a> or the <a href = "%2$s">network</a> if you are using a WordPress multi-system.',
                                'Message Error',
                                'cf7-event-tracker'
                            ),
                            '/wp-admin/plugins.php',
                            '/wp-admin/network/plugins.php'
                        );
                        break;
                    default:
                        // License not found
                        $msg = _x(
                            'An undefined Error happend in CF7 Event Tracker',
                            'Message Error',
                            'cf7-event-tracker'
                        );
                        break;
                }

            }

            new AdminError( $msg );

            /*
                1xx: License Messages
                    101: General License-Error
                    102: License was activated
                    103: License is expired
                    104: License could not be found

                2xx: Server Errors
                    201: Server is currently offline or not found

                3xx: Update Errors
                    301: Update-Class can't be loaded
            */

        }

    }

?>