<?php

    namespace CF7EventTracker;

    class Debug {

        protected $messages;
        protected $start_time;

        function __construct() {
            
            $this->messages = array();
            $this->start_time = time();

        }

        public function init_debugger() {

            $GLOBALS[ 'DEBUGGER' ] = $this;
            $this->add_hook_messages();

            $this->print_debug_messages();

        }

        protected function add_hook_messages() {

            add_action( 'plugins_loaded', function() {
                $this::add_msg( 'plugins_loaded', 'add_hook_messages', 'Debug' );
            });
            add_action( 'init', function() {
                $this::add_msg( 'init', 'add_hook_messages', 'Debug' );
            });
            add_action( 'wp_loaded', function() {
                $this::add_msg( 'wp_loaded', 'add_hook_messages', 'Debug' );
            });
            add_action( 'wp', function() {
                $this::add_msg( 'wp', 'add_hook_messages', 'Debug' );
            });
            add_action( 'wp_enqueue_scripts', function() {
                $this::add_msg( 'wp_enqueue_scripts', 'add_hook_messages', 'Debug' );
            });
            add_action( 'wp_head', function() {
                $this::add_msg( 'wp_head', 'add_hook_messages', 'Debug' );
            });
            
            add_action( 'shutdown', function() {
                $this::add_msg( 'shutdown', 'add_hook_messages', 'Debug' );
            });

        }

        public function print_debug_messages() {

            add_action( 'shutdown', function() {
                echo $this::get_msg();
            }, 9999 );

        }

        public static function add_msg( $msg, $function="", $class="" ) {

            $GLOBALS[ 'DEBUGGER' ]->add_debug_msg( $msg, $function, $class );

        }

        public function add_debug_msg( $msg, $function="", $class="" ) {

            $this->messages[] = array(
                'time'      => time(),
                'message'   => $msg,
                'function'  => $function,
                'class'     => $class
            );

        }

        public static function get_msg() {

            return $GLOBALS[ 'DEBUGGER' ]->get_debug_msg();

        }

        public function get_debug_msg() {

            ob_start();

            if( !function_exists( 'current_user_can' ) )
                return "";

            if( !current_user_can('administrator') || $_GET[ 'debug' ] != "on" )
                return "";

            $admin_style = "left: 0px;";
            if( is_admin() )
                $admin_style = "left: 180px;";

            ?>
                <div id="debug" style="position: fixed; bottom: 0; right: 0; height: 25%; overflow-y: scroll; z-index: 9999; <?php echo $admin_style; ?>">
                    <table border="1" cellspacing="0" cellpadding="5" width="100%">
                        <thead>
                            <tr>
                                <th align="left" width="20%" style="background: #000; color: #fff;">&nbsp;</th>
                                <th align="left" width="20%" style="background: #000; color: #fff;">Timestamp</th>
                                <th align="left" width="20%" style="background: #000; color: #fff;">Message</th>
                                <th align="left" width="20%" style="background: #000; color: #fff;">Function</th>
                                <th align="left" width="20%" style="background: #000; color: #fff;">Class</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php
                                foreach( $this->messages as $key => $msg ) {
                                    
                                    $cell_style = "background: #fff; color: #000;";
                                    if( $msg[ 'function' ] == 'add_hook_messages' && $msg[ 'class' ] == 'Debug' )
                                        $cell_style = "background: #666; color: #fff;";
                                    
                                    ?>
                                        <tr>
                                            <td style="<?php echo $cell_style; ?>">
                                                <?php echo $key; ?>
                                            </td>
                                            <td style="<?php echo $cell_style; ?>">
                                                t +<?php echo $msg[ 'time' ] - $this->start_time; ?> ms
                                            </td>
                                            <td style="<?php echo $cell_style; ?>">
                                                <?php echo $msg[ 'message' ]; ?>
                                            </td>
                                            <td style="<?php echo $cell_style; ?>">
                                                <?php echo $msg[ 'function' ]; ?>
                                            </td>
                                            <td style="<?php echo $cell_style; ?>">
                                                <?php echo $msg[ 'class' ]; ?>
                                            </td>
                                        </tr>
                                    <?php
                                }
                            ?>
                        </tbody>
                    </table>
                </div>
            <?php

            $messages = ob_get_clean();

            return $messages;

        }

    }

?>