<?php

    namespace CF7EventTracker;

    class Save {

        // ToDo: Save-Funktion muss noch einmal komplett überarbeitet werden. 
        //       Es sollten die Felder entsprechend als Arrays in den Input-Fields vorkommen. 
        //       Dadurch kann eine gezieltere Sicherungs-Funktion erstellt werden.

        private $options;
        private $settings;
        private $fields;

        function __construct() {
            
            $save_from_cf7form = array_key_exists( 'wpcf7-save', $_POST );
            $save_from_cf7et = array_key_exists( 'save_cf7_ga', $_POST );

            if( $save_from_cf7form || $save_from_cf7et ) {

                $this->options = \get_option( 'cf7_ga_tracking' );
                if( empty( $this->options ) ) {
                    $this->options = array(
                        'fields'    => array(),
                        'settings'  => array()
                    );
                }
                $this->fields = $this->options[ 'fields' ];
                $this->settings = $this->options[ 'settings' ];

                $this->save_fields();
                $this->save_settings();

                // Combine Settings and Fields
                $this->options[ 'fields' ] = $this->fields;
                $this->options[ 'settings' ] = $this->settings;

                // Update Settings
                \update_option( 'cf7_ga_tracking', $this->options );

            }

        }

        #region Fields
            private function get_fields_normal() {

                return array(
                    'cf7'			=> array(
                        'id'			=> '',
                    ),
                    'analytics'		=> array(
                        'campaign'		=> '',
                        'action'		=> '',
                        'label'			=> '',
                        'value'			=> ''
                    ),
                    'js' 			=> array(
                        'script'		=> ''
                    ),
                    'hubspot'		=> array(
                        'activated'	        	=>  'inactive',
                        'subject'		        =>  '',
                        'message'		        =>  '',
                        'create-customer'		=>	'inactive',
                        'customer-firstname'	=>	'',
                        'customer-lastname'		=>	'',
                        'customer-email'		=>	'',
                        'customer-website'		=>	'',
                        'customer-company'		=>	'',
                        'customer-phone'		=>	'',
                        'customer-address'		=>	'',
                        'customer-city'			=>	'',
                        'customer-state'		=>	'',
                        'customer-zip'			=>	''
                    )
                );

            }

            private function save_fields() {

                $isWPCF7Save = array_key_exists( 'wpcf7-save', $_POST );
                $isCF7ETSave = array_key_exists( 'save_cf7_ga', $_POST );
                $isCF7ETValExisting = array_key_exists( 'cf7val', $_POST );
                if( ( !$isCF7ETSave && !$isWPCF7Save ) || !$isCF7ETValExisting ) {
                    return false;
                }
                
                $special_key = null;
                if( array_key_exists( 'wpcf7-save', $_POST ) ) {

                    // Can just be a single Form
                    if( count( $_POST['cf7val'] ) == 1 ) {

                        // Key for Form-Edit in CF7-Form
                        $special_key = array_keys( $_POST['cf7val'] )[0];
                        if( $special_key == -1 ) {
                            $special_key = count( $this->fields );
                        }

                    }

                }

                if( !empty( $_POST['cf7val'] ) ) {
                    foreach( $_POST['cf7val'] as $key => $fieldset ) {

                        if( $special_key != null ) {
                            $key = $special_key;
                        }

                        $tmpFieldset = array();
                        $isFormEmpty = json_encode( $this->get_fields_normal() ) == json_encode( $fieldset );
                        if( !$isFormEmpty ) {

                            $tmpFieldset = array_merge( $this->get_fields_normal(), $fieldset );

                        }
                        
                        if( is_array( $this->fields[ $key ] ) ) {

                            foreach( array_keys( $this->fields[ $key ] ) as $fieldsetKey ) {

                                if( array_key_exists( $fieldsetKey, $tmpFieldset ) ) {

                                    foreach( array_keys( $tmpFieldset[ $fieldsetKey ] ) as $fieldKey ) {

                                        $fieldValue = \sanitize_textarea_field( $tmpFieldset[ $fieldsetKey ][ $fieldKey ] );
                                        if( $fieldsetKey == "cf7" && $fieldKey == "id" ) {

                                            $this->fields[ $key ][ $fieldsetKey ][ $fieldKey ] = $this->save_field_cf7id( $fieldValue );

                                        }
                                        else {

                                            $this->fields[ $key ][ $fieldsetKey ][ $fieldKey ] = "$fieldValue";

                                        }

                                    }

                                }

                            }

                        }
                        else {

                            $this->fields[ $key ] = $tmpFieldset;

                        }

                    }
                }
                
                $this->fields_garbage_collector();

            }
            private function save_field_cf7id( $fieldValue ) {

                if( is_numeric( $fieldValue ) ) {

                    // Check if given ID is CF7-Form
                    $current_post = \get_post( $fieldValue );
                    if( $current_post->post_type == "wpcf7_contact_form" ) {

                        return $fieldValue;

                    }

                }

                return "";

            }

            private function fields_garbage_collector() {

                foreach( $this->fields as $field_key => $field ) {
                    $fields_empty = true;
                    foreach( $field as $key => $value ) {
                        if( count( array_filter( $value, function( $k ) { return ( !empty( $k ) && $k != "inactive" ); } ) ) > 0 ) {
                            $fields_empty = false;
                        }
                    }
                    if( $fields_empty ) {
                        unset( $this->fields[ $field_key ] );
                    }
                }

            }
        #endregion

        #region Settings
            private function save_settings() {

                if( !in_array( $_GET[ 'page' ], array( 'cf7_events' ) ) ) {
                    return false;
                }
                if( !array_key_exists( 'save_cf7_ga', $_POST ) ) {
                    return false;
                }

                \delete_transient( 'license_status' );

                if( empty( $this->settings ) ) {
                    $this->settings = array(
                        'function'			=> '',
                        'function_type'     => '',
                        'tracking'			=> '',
                        'ga_errors'			=> '',
                        'hubspot_api'		=> '',
                        'reduced_scripts'   => ''
                    );
                }
                
                #region License
                    $license = \get_network_option( null, 'cf7et-license', '' );
                    if( array_key_exists( 'cf7_ga_tracking_license', $_POST ) ) {

                        $license = $_POST[ 'cf7_ga_tracking_license' ];
                        $license = \sanitize_text_field( $license );

                        \update_network_option( null, 'cf7et-license', $license );

                    }
                #endregion


                #region Google Analytics Settings
                    $tracking_function = $this->settings[ 'function' ];
                    if( array_key_exists( 'gatracking_function', $_POST ) ) {

                        $tracking_function = $_POST[ 'gatracking_function' ];
                        $tracking_function = \sanitize_text_field( $tracking_function );

                    }

                    $tracking_function_type = $this->settings[ 'function_type' ];
                    if( array_key_exists( 'gatracking_function_type', $_POST ) ) {

                        $tracking_function_type = $_POST[ 'gatracking_function_type' ];
                        $tracking_function_type = \sanitize_text_field( $tracking_function_type );

                    }

                    $analytics_errors = $this->settings[ 'ga_errors' ];
                    if( array_key_exists( 'analytics_error_analysis', $_POST ) ) {

                        $analytics_errors = $_POST[ 'analytics_error_analysis' ];
                        $analytics_errors = \sanitize_text_field( $analytics_errors );

                    }
                    else {
                        $analytics_errors = "";
                    }
                #endregion


                #region WordPress Settings
                    $system_tracking = $this->settings[ 'tracking' ];
                    if( array_key_exists( 'system_tracking', $_POST ) ) {

                        $system_tracking = $_POST[ 'system_tracking' ];
                        $system_tracking = \sanitize_text_field( $system_tracking );

                    }
                    else {
                        $system_tracking = "";
                    }

                    $reduced_scripts = $this->settings[ 'reduced_scripts' ];
                    if( array_key_exists( 'reduced_scripts', $_POST ) ) {

                        $reduced_scripts = $_POST[ 'reduced_scripts' ];
                        $reduced_scripts = \sanitize_text_field( $reduced_scripts );

                    }
                    else {

                        $reduced_scripts = "";

                    }
                #endregion

                
                #region HubSpot Settings
                    $hubspot_api_key = $this->settings[ 'hubspot_api' ];
                    if( array_key_exists( 'hubspot_api_key', $_POST ) ) {

                        $hubspot_api_key = $_POST[ 'hubspot_api_key' ];
                        $hubspot_api_key = \sanitize_text_field( $hubspot_api_key );

                    }
                #endregion

                $this->settings = array(
                    'function'			=> $tracking_function,
                    'function_type'     => $tracking_function_type,
                    'tracking'			=> $system_tracking,
                    'ga_errors'			=> $analytics_errors,
                    'hubspot_api'		=> $hubspot_api_key,
                    'reduced_scripts'   => $reduced_scripts
                );

            }
        #endregion

    }
    
?>