<?php

    namespace CF7EventTracker;

    use \CPPluginCore\Options           as Options;
    use \CF7EventTracker\AdminError     as AdminError;
    use \CF7EventTracker\Sidebar        as Sidebar;
    use \CF7EventTracker\SettingsField  as SettingsField;
    use \CF7EventTracker\InputField     as InputField;
    use \CF7EventTracker\Save           as Save;

    class PluginOptions extends Options {
        
        private $options;
        private $fields;
        private $settings;

        function __construct( $page_id, $parent_id=false, $capabilities="administrator" ) {

            parent::__construct( $page_id, $parent_id, $capabilities );

            $this->load_dependencies();
            $this->init_page_content( $page_id );

        }

        private function init_page_content( $page_id ) {

            if( $_GET[ 'page' ] == $page_id ) {

                if( class_exists( '\CF7EventTracker\Save' ) ) {
                    new Save();
                }
                else {
                    AdminError::get_error( 302 );
                }
    
                $this->options = \get_option( 'cf7_ga_tracking' );
                $this->fields = $this->options[ 'fields' ];
                $this->settings = $this->options[ 'settings' ];
    
                add_filter( 'cpc_option_page_parts', array( $this, 'custom_resolve_page_parts' ), 10, 1 );
                add_filter( 'cpc_options_page_structure', array( $this, 'custom_page_structure' ), 10, 1 );
                
            }
            
        }

        private function load_dependencies() {

            require_once( CF7ET_PATH . "inc/global/backend/fields/SettingsField.php" );
            require_once( CF7ET_PATH . "inc/global/backend/fields/InputField.php" );

        }

        #region Page Areas
            public function get_content() {

                $setting_areas = array(
                    array(
                        'title'     => _x( 'Global Settings', 'Options Title', 'cf7-event-tracker' ),
                        'content'   => $this->get_main_settings()
                    )
                );

                ob_start();
                foreach( $setting_areas as $area ) {

                    ob_start();
                    ?>
                        <h3><?php echo $area[ 'title' ]; ?></h3>
                        <div class="area_wrapper">
                            <?php
                                echo $area[ 'content' ];
                            ?>
                        </div>
                    <?php
                    echo ob_get_clean();

                }
                return ob_get_clean();

            }
            public function get_header() {

                ob_start();
                ?>
                    <div class="theme_options_headline_wrapper">
                        <div class="theme_options_headline_background"></div>
                        <div class="theme_options_headline_image">
                            <img src="/wp-content/plugins/cf7-event-tracker/img/codepalm_black.png">
                        </div>
                        <div class="theme_options_headline_title">
                            <div class="theme_options_headline_title_wrapper">
                                <h1>CF7 Event Tracker</h1>
                                <span><?php echo _x( 'Settings', 'Options Label', 'cf7-event-tracker' ); ?></span>
                            </div>
                        </div>
                        <div style="clear: both;"></div>
                    </div>
                <?php
                return ob_get_clean();

            }
            public function get_footer() {

                ob_start();
                ?>
                    <p><?php echo sprintf( _x( '%1$s is a project of %2$s.', 'Options Content', 'cf7-event-tracker' ), '<strong>CF7 Event Tracker</strong>', '<a href="https://www.codepalm.de/" target="_blank" style="text-decoration: none;">Codepalm</a>' ); ?></p>
                <?php
                return ob_get_clean();

            }
            public function get_sidebar() {

                ob_start();
                ?>
                    <h4>Wissenswertes</h4>
                    <?php
                        $sidebar = new Sidebar();
                        echo $sidebar->get_sidebar_content();
                    ?>
                <?php
                return ob_get_clean();

            }
        #endregion

        #region Content Areas

            #region Main Settings
                private function get_main_settings() {
                    
                    $field = new InputField(
                        array(
                            'type'          => 'input',
                            'id'			=> 'cf7_ga_tracking_license',
                            'value'			=> \get_network_option( null, 'cf7et-license', '' ),
                            'label'			=> sprintf( \_x( 'Enter your license here. Visit <a href="%1$s" target="_blank">Codepalm.de</a>, to create a license.', 'Options Content', 'cf7-event-tracker' ), "https://www.codepalm.de/" )
                        )
                    );
                    $settings_area = new SettingsField(
                        $field, 
                        array(
                            'title'				=> \_x( 'CF7 Event Tracker License', 'Options Title', 'cf7-event-tracker' ),
                            'description'		=> sprintf( \_x( 'With a valid license you will get updates for the plugin. If your license expires, you can still use the plugin, but you will not receive any important updates. %1$s', 'Options Content', 'cf7-event-tracker' ), $this->get_license_informations() )
                        )
                    );
                    return $settings_area->get_field_area();

                }
                private function get_license_informations() {

                    $license = \get_network_option( null, 'cf7et-license', '' );
                    $remote = "https://update.codepalm.de";
                    $origin = $_SERVER[ 'SERVER_NAME' ];

                    $messages = array();
                    $status = "error"; // error; success; warning
                    $license_informations = \get_transient( 'license_status' );
                    if( empty( $license_informations ) ) {

                        $url = "$remote/wp-json/check_license/v1/cf7-event-tracker/$license/$origin/";

                        if( !empty( $license ) ) {

                            #region Get current license Informations from remote
                                $ch = curl_init();
                                curl_setopt( $ch, CURLOPT_URL, $url );

                                ob_start();
                                curl_exec( $ch );
                                $curl_result = json_decode( ob_get_clean(), true );
                                curl_close( $ch );
                            #endregion

                            #region Register license if neccessary
                                $domain_registered  = in_array( $origin, array_column( $curl_result[ 'registered_sites' ], 'domain' ) );
                                $registrations_left = intval( $curl_result[ 'registrations_left' ] );
                                $expires            = intval( $curl_result[ 'license_expires' ] );

                                if( !$domain_registered && $registrations_left > 0 ) {

                                    $url = "$remote/wp-json/register_license/v1/cf7-event-tracker/$license/$origin";

                                    $ch = curl_init();
                                    curl_setopt( $ch, CURLOPT_URL, $url );

                                    ob_start();
                                    curl_exec( $ch );
                                    $curl_result = json_decode( ob_get_clean(), true );
                                    $curl_result = $curl_result[ 'data' ];
                                    curl_close( $ch );

                                }
                            #endregion

                            #region Setup status messages
                                $domain_registered  = in_array( $origin, array_column( $curl_result[ 'registered_sites' ], 'domain' ) );
                                $registrations_left = intval( $curl_result[ 'registrations_left' ] );
                                $expires            = intval( $curl_result[ 'license_expires' ] );

                                if( $domain_registered ) {
                                    $messages[] = \_x( "Your current domain is registered.", 'Message Success', 'cf7-event-tracker' );
                                    $status = "success";
                                }
                                else {
                                    $messages[] = \_x( "Your domain is not registered.", 'Message Error', 'cf7-event-tracker' );
                                    $status = "error";
                                }

                                if( $registrations_left > 0 ) {
                                    $messages[] = \_x( "You can activate $registrations_left websites with this license key.", 'Message Info', 'cf7-event-tracker' );
                                }
                                else {
                                    $messages[] = \_x( "You can't register any more websites with this license key.", 'Message Warning', 'cf7-event-tracker' );
                                }
                            #endregion

                        }
                        else {

                            // License isn't provided yet
                            $messages[] = \_x( "Please insert your license to receive upcomming updates.", 'Message Error', 'cf7-event-tracker' );
                            $status = "warning";

                        }

                        #region Save Informations in  Transient
                            $transient_data = array(
                                'messages'  => $messages,
                                'status'    => $status,
                                'expires'   => $expires
                            );
                            \set_transient( 'license_status', $transient_data, 86400 ); // Transient expires in 1 day
                        #endregion

                    }
                    else {

                        $messages = $license_informations[ 'messages' ];
                        $status = $license_informations[ 'status' ];
                        $expires = $license_informations[ 'expires' ];

                    }

                    $result_message = sprintf( '<div class="notice notice-%2$s notice-alt" style="margin: 15px 0 0 0; padding: 5px 15px;">%1$s</div>', join( '<br/>', $messages ), $status );
                    

                    // Set Error-Messages for exirations if license is available
                    if( !empty( $license ) && in_array( $status, array( "success", "warning" ) ) ) {

                        $days_left_until_expires = round( ( $expires - time() ) / ( 60 * 60 * 24 ) );
                        if( date( 'Y-m-d', $expires ) != '2099-12-31' ) {

                            // Is not Lifetime-License
                            if( $days_left_until_expires <= 0 ) {

                                // License has been expired
                                $license_expiration_message  = \_x( "Your license has expired.", 'Message Error', 'cf7-event-tracker' );
                                $license_expiration_message .= "<br/>";
                                $license_expiration_message .= sprintf( \_x( "You should renew your license as soon as possible on <a href='%s' target='_blank'>Codepalm.de</a>.", 'Message Error', 'cf7-event-tracker' ), "https://www.codepalm.de/plugins/cf7-event-tracker" );
                                $license_expiration_message .= sprintf( \_x( "Don't want to renew your license every year? <a href='%s' target='_blank'>Get a lifetime license now!</a>", 'Message Error', 'cf7-event-tracker' ), "https://www.codepalm.de/plugins/cf7-event-tracker" );

                                $result_message .= sprintf( '<div class="notice notice-error notice-alt" style="margin: 15px 0 0 0; padding: 5px 15px;">%1$s</div>', $license_expiration_message );

                            }
                            else if( $days_left_until_expires <= 14 ) {
                                
                                // License expires in the next few days
                                $license_expiration_message  = sprintf( \_x( "Your license expires in <strong>%s days</strong>.", 'Message Warning', 'cf7-event-tracker' ), $days_left_until_expires );
                                $license_expiration_message .= "<br/>";
                                $license_expiration_message .= sprintf( \_x( "You should renew your license as soon as possible on <a href='%s' target='_blank'>Codepalm.de</a>.", 'Message Warning', 'cf7-event-tracker' ), "https://www.codepalm.de/plugins/cf7-event-tracker" );
                                $license_expiration_message .= sprintf( \_x( "Don't want to renew your license every year? <a href='%s' target='_blank'>Get a lifetime license now!</a>", 'Message Warning', 'cf7-event-tracker' ), "https://www.codepalm.de/plugins/cf7-event-tracker" );

                                $result_message .= sprintf( '<div class="notice notice-warning notice-alt" style="margin: 15px 0 0 0; padding: 5px 15px;">%1$s</div>', $license_expiration_message );

                            }

                        }

                    }

                    return $result_message;

                }
            #endregion

        #endregion

        #region Save Mask
            private function get_save_mask() {

                ob_start();
                ?>
                    <div class="row">
                        <div class="col-9">
                            <span style="display: block; margin-top: 6px"><strong><?php echo _x( 'Remember to test your Forms, if you carry out changes!', 'Options Label', 'cf7-event-tracker' ); ?></strong></span>
                        </div>
                        <div class="col-3 text-right">
                            <input type="submit" name="save_cf7_ga" id="save_cf7_ga" class="button button-primary button-large menu-save" value="<?php echo _x( 'Save Settings', 'Options Label', 'cf7-event-tracker' ); ?>">
                        </div>
                    </div>
                <?php
                return ob_get_clean();

            }
        #endregion

        #region Custom Structures
            public function custom_page_structure( $structure ) {

                ob_start();
                ?>
                    <div id="cf7-event-tracker">
                        <div id="plugin_page">
                            <div id="plugin_header" class="no-bg">
                                %HEADER%
                            </div>
                            <form id="cf7-event-tracker-form" method="POST" action="<?php echo get_permalink(); ?>">
                                <div id="plugin_save_bar">
                                    %SAVE_MASK%
                                </div>
                                <div id="plugin_body">
                                    <div id="plugin_content">
                                        %CONTENT%
                                    </div>
                                    <div id="plugin_sidebar">
                                        %SIDEBAR%
                                    </div>
                                </div>
                            </form>
                            <div id="pugin_footer" class="no-bg">
                                %FOOTER%
                            </div>
                        </div>
                    </div>
                <?php
                return ob_get_clean();

            }
            public function custom_resolve_page_parts( $replacements ) {

                $replacements[ '%SAVE_MASK%' ] = $this->get_save_mask();

                return $replacements;

            }
        #endregion
        
    }

?>