<?php

    namespace CF7EventTracker;

    /*
        $args = array(
            'type'          => '',
            'id'            => '',
            'value'         => '',
            'placeholder'   => '',
            'class'         => '',
            'style'         => '',
            'label'         => '',
            'list'          => '',
            'readonly'      => false,
            'hint'          => array(
                'title'         => '',
                'description'   => ''
            )
        );
        $field = new InputField( $args );
    */
    class InputField {

        private $type;
        private $id;
        private $value;
        private $placeholder;
        private $style;
        private $class;
        private $label;
        private $list;
        private $readonly;
        private $hint;

        function __construct( $args ) {
            
            $this->type         = $args[ 'type' ];
            $this->id			= $args[ 'id' ];
            $this->value		= $args[ 'value' ] ?: '';
            $this->placeholder	= $args[ 'placeholder' ] ?: '';
            $this->style		= $args[ 'style' ] ?: '';
            $this->class		= $args[ 'class' ] ?: '';
            $this->label		= $args[ 'label' ];
            $this->list			= $args[ 'list' ] ?: '';
            $this->readonly		= $args[ 'readonly' ] ?: '';

            if( !empty( $args[ 'hint' ] ) ) {

                $this->hint     = array_merge(
                    // Default
                    array(
                        'title'         => '',
                        'description'   => ''
                    ),
                    // Custom
                    $args[ 'hint' ]
                );

            }

        }

        #region Get Field
            public function get_field() {

                $structure = "";
                switch( $this->type ) {

                    case 'input':
                        $structure = $this->get_input_field_structure();
                        break;
                    
                    case 'textarea': 
                        $structure = $this->get_textarea_field_structure();
                        break;
                    
                    case 'checkbox': 
                        $structure = $this->get_checkbox_field_structure();
                        break;
                    
                    case 'dropdown': 
                        $structure = $this->get_dropdown_field_structure();
                        break;
                    
                }

                // Structure shouldn't be empty (appears, if type == undefined)
                if( $structure == "" ) {
                    return "";
                }

                // Value has to be array if type is "dropdown"
                if( $this->type == "dropdown" && !is_array( $this->value ) ) {
                    return "";
                }
                
                return $this->replace_field_placeholders( $structure );

            }
        #endregion

        #region Field Structures
            private function get_input_field_structure() {

                ob_start();
                ?>
                    <div class="input_hint_wrapper">
                        <input
                            type="text"
                            list="%LIST%"
                            class="%CLASS%"
                            style="%STYLE%"
                            name="%NAME%"
                            id="%ID%"
                            placeholder="%PLACEHOLDER%"
                            value="%VALUE%"
                            %READONLY%
                        />
                        %LABEL%
                        %HINT%
                    </div>
                <?php
                return ob_get_clean();

            }
            private function get_textarea_field_structure() {

                ob_start();
                ?>
                    <div class="input_hint_wrapper">
                        <textarea
                            type="text"
                            class="%CLASS%"
                            style="%STYLE%"
                            name="%NAME%"
                            id="%ID%"
                            placeholder="%PLACEHOLDER%"
                            %READONLY%
                        >%VALUE%</textarea>
                        %LABEL%
                        %HINT%
                    </div>
                <?php
                return ob_get_clean();

            }
            private function get_checkbox_field_structure() {

                ob_start();
                ?>
                    <div class="checkbox_wrapper">
                        <input
                            type="hidden"
                            name="%NAME%"
                            id="%ID_HIDDEN%"
                            value="%VALUE_INACTIVE%"
                        />
                        <input
                            type="checkbox"
                            class="%CLASS%"
                            name="%NAME%"
                            id="%ID%"
                            value="%VALUE_ACTIVE%"
                            %CHECKED%
                        />
                        %HINT%
                        %LABEL%
                    </div>
                <?php
                return ob_get_clean();

            }
            private function get_dropdown_field_structure() {

                ob_start();
                ?>
                    <select id="%ID%" name="%NAME%">
                        %DROPDOWN%
                    </select>
                    %LABEL%
                <?php
                return ob_get_clean();

            }
            private function get_dropdown_option_structure() {

                ob_start();
                ?>
                    <option
                        value="%VALUE%"
                        %DISABLED%
                        %SELECTED%
                    >
                        %LABEL%
                    </option>
                <?php
                return ob_get_clean();

            }

            private function get_label_structure() {
                
                ob_start();
                ?>
                    <label for="%ID%">
                        %MESSAGE%
                    </label>
                <?php
                return ob_get_clean();

            }

            private function get_hint_structure() {
                
                ob_start();
                ?>
                    <span class="hint">
                        <strong>%HINT_TITLE%</strong><br/>
                        %HINT_DESCRIPTION%
                    </span>
                <?php
                return ob_get_clean();

            }
        #endregion

        #region Setup Replacements
            private function replace_field_placeholders( $structure=null ) {

                if( empty( $structure ) ) {
                    $structure = $this->get_input_field_structure();
                }

                $replacements = array(

                    // Globals
                    'ID'                => $this->id,
                    'NAME'              => $this->id,
                    'VALUE'             => ( ( !is_array( $this->value ) ) ? $this->value : '' ),
                    'CLASS'             => $this->class,
                    'STYLE'             => $this->style,

                    // Dropdown Values
                    'DROPDOWN'          => ( ( $this->type == "dropdown" && is_array( $this->value ) ) ? $this->value : '' ),

                    // Checkbox Values
                    'ID_HIDDEN'         => $this->id.'_hidden',
                    'NAME_HIDDEN'       => $this->id.'_hidden',
                    'VALUE_ACTIVE'      => 'activated',
                    'VALUE_INACTIVE'    => 'inactive',
                    'CHECKED'           => ( ( $this->type == "checkbox" && $this->value == "activated" ) ? 'checked="checked"' : '' ),

                    // Misc
                    'PLACEHOLDER'       => $this->placeholder,
                    'READONLY'          => ( ( $this->readonly === true ) ? 'readonly' : '' ),
                    'LIST'              => $this->list,

                    // Additional
                    'LABEL'             => $this->replace_label_placeholders(),
                    'HINT'              => $this->replace_hint_placeholders()

                );
                
                return $this->replace_placeholders( $structure, $replacements );

            }

            private function replace_label_placeholders( $structure=null ) {

                if( empty( $this->label ) ) {
                    return "";
                }

                if( empty( $structure ) ) {
                    $structure = $this->get_label_structure();
                }

                $replacements = array(
                    'ID'            => $this->id,
                    'MESSAGE'       => $this->label
                );

                return $this->replace_placeholders( $structure, $replacements );

            }

            private function replace_hint_placeholders( $structure=null ) {

                if( empty( $this->hint ) ) {
                    return "";
                }

                if( empty( $structure ) ) {
                    $structure = $this->get_hint_structure();
                }

                $replacements = array(
                    'HINT_TITLE'        => $this->hint[ 'title' ],
                    'HINT_DESCRIPTION'  => $this->hint[ 'description' ]
                );

                return $this->replace_placeholders( $structure, $replacements );

            }
        #endregion

        #region Replace Algorithm
            private function replace_placeholders( $structure, $replacements ) {

                foreach( $replacements as $replace => $value ) {

                    $placeholder = "%$replace%";

                    if( !is_array( $value ) ) {
                        
                        $structure = str_replace( $placeholder, stripslashes( $value ), $structure );

                    }
                    else {

                        // Special Case: Dropdown Value Array
                        if( $placeholder == "%DROPDOWN%" ) {

                            $dropdown_structure = $this->get_dropdown_option_structure();
                            $dropdown_options = "";
                            foreach( $value as $dropdown_option_values ) {

                                $dropdown_options .= $this->replace_placeholders( $dropdown_structure, $dropdown_option_values );

                            }
                            $structure = str_replace( $placeholder, $dropdown_options, $structure );

                        }

                    }

                }

                return $structure;

            }
        #endregion

    }

?>