<?php
	
	namespace CF7EventTracker\Help;

	class HelpPages {

		private $user_lang;

		public function register_hooks() {

			add_action( 'admin_init', array( $this, 'set_user_language' ) );
			add_action( 'current_screen', array( $this, 'setup_help_pages' ) );

		}

		public function set_user_language() {

			$this->user_lang = 'en';
			if( explode( '_', \get_user_locale( get_current_user_id() ) )[ 0 ] == 'de' ) {
				$this->user_lang = 'de';
			}

		}

		public function setup_help_pages() {

			$screen = get_current_screen();
			$screen->add_help_tab(
				array(
					'id'		=> 'event_tracker_help_tab_about',
					'title'		=> _x( 'About', 'HelpPage Tab', 'cf7-event-tracker' ),
					'content'	=> HelpPages::cf7_event_tracker_help_about( $this->user_lang )
				)
			);
			$screen->add_help_tab(
				array(
					'id'		=> 'event_tracker_help_tab_configuration',
					'title'		=> _x( 'Configuration', 'HelpPage Tab', 'cf7-event-tracker' ),
					'content'	=> HelpPages::cf7_event_tracker_help_configuration( $this->user_lang )
				)
			);
			$screen->add_help_tab(
				array(
					'id'	=> 'event_tracker_help_tab_scripts',
					'title'	=> _x( 'JavaScript', 'HelpPage Tab', 'cf7-event-tracker' ),
					'content'	=> HelpPages::cf7_event_tracker_help_javascript( $this->user_lang )
				)
			);
			$screen->add_help_tab(
				array(
					'id'	=> 'event_tracker_help_tab_hubspot',
					'title'	=> _x( 'HubSpot', 'HelpPage Tab', 'cf7-event-tracker' ),
					'content'	=> HelpPages::cf7_event_tracker_help_hubspot( $this->user_lang )
				)
			);

		}

		public static function cf7_event_tracker_help_about( $user_lang ) {

			ob_start();
			if( true ) {
				?>
	
					<p>&nbsp;</p>
					<!--
						Über das CF7-Event-Tracker Plugin
					-->
					<h1><?php echo _x( 'About the CF7-Event-Tracker Plugin', 'HelpPage Title', 'cf7-event-tracker' ); ?></h1>
					<p>&nbsp;</p>
	
					<!--
						Mit dem CF7-Event-Tracking Plugin von Codepalm erhalten deine Contact Form 7 Kontaktformulare eine breitere Pallette an Funktionen.<br/>
						Neben der Verfolgung von Kontaktanfragen in Google Analytics oder anderen Analyse-Tools beinhaltet das Plugin eine Anbindung an HubSpot, eine Integration von individuellem JavaScript und noch mehr.
					-->
					<p><?php echo _x( 'With the CF7 event tracking plugin from Codepalm, your Contact Form 7 contact forms receive a wider range of functions.<br/>
					In addition to tracking contact requests in Google Analytics or other analysis tools, the plugin includes a connection to HubSpot, an integration of individual JavaScript and more.', 'HelpPage Content', 'cf7-event-tracker' ); ?></p>
	
					<!-- 
						Alle Funktionen des Plugins auf einen Blick:
					-->
					<h3><?php echo _x( 'All functions of the plugin at a glance:', 'HelpPage Title', 'cf7-event-tracker' ); ?></h3>
					<ul>
						<li>
							<!--
								Google Analytics Tracking
							-->
							<strong><?php echo _x( 'Google Analytics Tracking', 'HelpPage Title', 'cf7-event-tracker' ); ?></strong><br/>
							<!--
								Egal ob du den Google Tag Manager, das Google Analytics Universal Tracking oder das Google Analytics Classic Tracking auf deiner Seite integriert hast - Mit dem CF7-Event-Tracking-Plugin kannst du die Anfragen auf deiner Webseite direkt in Google Analytics nachverfolgen.
							-->
							<?php echo _x( 'Regardless of whether you have integrated Google Tag Manager, Google Analytics Universal Tracking or Google Analytics Classic Tracking on your page - with the CF7 event tracking plugin you can track the requests on your website directly in Google Analytics.', 'HelpPage Content', 'cf7-event-tracker' ); ?>
						</li>
						<li>
							<!--
								Individuelles JavaScript
							-->
							<strong><?php echo _x( 'Custom JavaScript', 'HelpPage Title', 'cf7-event-tracker' ); ?></strong><br/>
							<!--
								Du möchtest nach einer erfolgreichen Kontaktanfrage noch mehr machen? Mit dem individuellem JavaScript kannst du den Besucher auf eine "Vielen Dank"-Seite weiterleiten lassen, oder weitere Informationen zu deiner Webseite oder deiner Firma ausgeben.
							-->
							<?php echo _x( 'Would you like to trigger specific JavaScript-Code after a successful contact request? With a textfield for individual JavaScript, you can have the visitor redirected to a "Thank you" page, or provide further information about your website or your company.', 'HelpPage Content', 'cf7-event-tracker' ); ?>
						</li>
						<li>
							<strong><?php echo _x( 'HubSpot Ticket-System', 'HelpPage Title', 'cf7-event-tracker' ); ?></strong><br/>
							<!--
								Mit dem CF7-Event-Tracking-Plugin behältst du die nicht-abgeschlossenen Anfragen immer im Überblick. Durch die automatische Erstellung eines Tickets in HubSpot weißt du ganz genau, welche Informationen du deinen Interessenten bereits gesendet hast.
							-->
							<?php echo _x( 'With the CF7 event tracking plugin you always keep an overview of the incomplete requests. By automatically creating a ticket in HubSpot, you know exactly what information you have already sent to your prospects.', 'HelpPage Content', 'cf7-event-tracker' ); ?>
						</li>
					</ul>
					
					<div style="text-align: center; padding: 40px 0 20px 0;">
						<a href="https://www.codepalm.de/" target="_blank">
							<img src="<?php echo CF7ET_URL . "img/codepalm_logo.png"; ?>" style="max-width: 80px;" />
						</a>
						<h3><?php echo sprintf( _x( '%1$s is a project of %2$s.', 'HelpPage Content', 'cf7-event-tracker' ), '<strong>CF7 Event Tracker</strong>', '<a href="https://www.codepalm.de/" target="_blank" style="text-decoration: none;">Codepalm</a>' ); ?></h3>
					</div>
	
					<p>&nbsp;</p>
					
				<?php
			}
			return ob_get_clean();
	
		}
	
		public static function cf7_event_tracker_help_configuration( $user_lang ) {
	
			ob_start();
			if( true ) {
				?>
	
					<p>&nbsp;</p>
					<!--
						Installation und Konfiguration des CF7-Event-Tracking Plugins
					-->
					<h1><?php echo _x( 'Installation and configuration of the CF7 event tracking plugin', 'HelpPage Title', 'cf7-event-tracker' ); ?></h1>
					<p>&nbsp;</p>
	
					<!--
						Vielen Dank, dass du den Contact Form 7 Event Tracker verwendest!
					-->
					<p><?php echo _x( 'Thank you for using the Contact Form 7 Event Tracker!', 'HelpPage Content', 'cf7-event-tracker' ); ?></p>
					<!--
						Hier erfährst du alles, was du zur Konfiguration und Verwendung des Plugins wissen solltest.
					-->
					<p><?php echo _x( 'Here you will find everything you need to know about configuring and using the plugin.', 'HelpPage Content', 'cf7-event-tracker' ); ?></p>
	
					<!--
						1. Einrichten der Lizenz
					-->
					<h3><?php echo _x( '1. Set up the license', 'HelpPage Title', 'cf7-event-tracker' ); ?></h1>
					<!--
						Sobald du das Plugin installiert hast, kann du unter "CF7 Event Tracker > Einstellungen" deinen Lizenz-Schlüssel eintragen.<br/>
					Du kannst das Plugin ohne Lizenz verwenden, aber erhaltest keine wichtigen Updates mehr.<br/>
					Stelle also sicher, dass du eine gültige Lizenz auf Codepalm.de erstellt hast, die du im Feld "CF7 Event Tracker Lizenz" eintragen kannst.<br/>
					Speichere die Änderungen und Update das Plugin, falls es eine neue Version geben sollte. Das Update kannst du unter "Plugins" herunterladen.
					-->
					<p><?php echo _x( 'As soon as you have installed the plugin, you can enter your license key under "CF7 Event Tracker> Settings".<br/>
						You can use the plugin without a license, but you will no longer receive important updates.<br/>
						So make sure that you have created a valid license on Codepalm.de, which you can enter in the field "CF7 Event Tracker License".<br/>
						Save the changes and update the plugin if there is a new version. You can download the update under "Plugins".', 'HelpPage Content', 'cf7-event-tracker' ); ?></p>
					<img src="<?php echo CF7ET_URL . 'img/howto/'.$user_lang.'/cf7_tracker_insert_license.jpg'; ?>" />
	
					<p>&nbsp;</p>
	
					<!--
						2. Google Analytics einrichten
					-->
					<h3><?php echo _x( '2. Set up Google Analytics', 'HelpPage Title', 'cf7-event-tracker' ); ?></h3>
					<!--
						Wenn du Google Analytics zur Analyse deiner Kontaktformulare verwenden möchtest, solltest du zuerst sicherstellen, dass der Google Analytics Tracking-Code auf deiner Webseite integriert ist.<br/>
						Schau dazu im Frontend deiner Webseite in den Quellcode (Strg + U) und Suche (Strg + F) nach einem der Schlüsselwörter "ga", "_gaq" oder "gtag".<br/>
						Solltest du keine Ergebnisse zu dieser Suche erhalten, weißt du, dass Google Analytics sehr wahrscheinlich nicht auf deiner Webseite integriert ist.<br/>
						Folge der Anleitung auf Google Analytics, um den Tracking-Code zu integrieren.
					-->
					<p><?php echo _x( 'If you want to use Google Analytics to analyze your contact forms, you should first ensure that the Google Analytics tracking code is integrated on your website.<br/>
						Look in the front end of your website in the source code (Ctrl + U) and search (Ctrl + F) for one of the keywords "ga", "_gaq" or "gtag".<br/>
						If you don\'t get results from this search, you know that Google Analytics is most likely not on your website.<br/>
						Follow the instructions on Google Analytics to integrate the tracking code.', 'HelpPage Content', 'cf7-event-tracker' ); ?></p>
					<img src="<?php echo CF7ET_URL . 'img/howto/'.$user_lang.'/cf7_tracker_google_analytics_code.jpg'; ?>" />
	
					<!--
						In diesem Code findest du auch heraus, welches Google Tracking-Script du verwendest.<br/>
						Wähle in den Plugin-Optionen das richtige Tracking aus und füge den Funktionsnamen von Google Analytics ein.<br/>
						Das Plugin hilft dir bei der Einrichtung, wenn du nicht weiter weißt.
					-->
					<p><?php echo _x( 'This code also tells you which Google tracking script you are using.<br/>
						Select the right tracking in the plugin options and insert the function name of Google Analytics.<br/>
						The plugin will help you set it up if you are stuck.', 'HelpPage Content', 'cf7-event-tracker' ); ?></p>
					<img src="<?php echo CF7ET_URL . 'img/howto/'.$user_lang.'/cf7_tracker_google_analytics_setup.jpg'; ?>" />
	
					<p>&nbsp;</p>
	
					<!--
						3. Das erste Tracking einrichten
					-->
					<h3><?php echo _x( '3. Set up the first tracking', 'HelpPage Title', 'cf7-event-tracker' ); ?></h3>
					<!--
						Wenn du schon ein Formular mit Contact Form 7 erstellt hast, kannst du gleich mit der Erstellung des Trackings loslegen.<br/>
						Du solltest entweder im Kontaktformular im Menüpunkt "Kontakt" oder im Menüpunkt "CF7 Event Tracker > Formulare" starten.<br/>
						In einem Formular in Contact Form 7 findest du den Reiter "Event Tracking", indem du die nachfolgenden Einstellungen vornehmen kannst.<br/>
						In "Formulare" befinden sich alle Event-Trackings für deine Kontaktformulare.
					-->
					<p><?php echo _x( 'If you have already created a form with Contact Form 7, you can start creating the tracking right away.<br/>
						You should either start in the contact form in the menu item "Contact" or in the menu item "CF7 Event Tracker > Forms".<br/>
						In a form in Contact Form 7 you will find the "Event Tracking" tab by making the following settings.<br/>
						"Event forms" contains all event tracking for your contact forms.', 'HelpPage Content', 'cf7-event-tracker' ); ?></p>
	
					<p>&nbsp;</p>
	
					<!--
						3.1. Google Analytics Ereignis erstellen
					-->
					<h3><?php echo _x( '3.1. Create Google Analytics event', 'HelpPage Title', 'cf7-event-tracker' ); ?></h3>
					<!--
						Um das Ereignis für Google Analytics einzurichten, musst du ein paar Informationen in die jeweiligen Felder eintragen.<br/>
						Wenn du das Tracking über die Einstellungen von "CF7 Event Tracker > Formulare" bearbeiten möchtest, musst du zunächst die ID des Formulars angeben.<br/>
						Klicke in das Feld, um alle Formulare zu sehen, die du bereits in CF7 eingerichtet hast und wähle das Formular aus, zu dem du ein Tracking einrichten möchtest.<br/>
						Solltest du das Tracking über die Option "Event Tracking" im CF7-Formular einrichten, musst du keine ID angeben. Diese wird automatisch gesetzt.<br/>
						Als nächstes benötigst du einen Kampagnen-Namen und einen Aktions-Namen. Diese beiden Werte werden von Google Analytics vorausgesetzt.<br/>
						Die Kampagne kann für ein Kontaktformular zum Beispiel "Kontakt" und die Aktion "Anfrage" lauten.
					-->
					<p><?php echo _x( 'To set up the event for Google Analytics, you have to enter some information in the respective fields.<br/>
						If you want to edit the tracking via the settings of "CF7 Event Tracker > Forms", you must first enter the ID of the form.<br/>
						Click in the field to see all the forms you have already set up in CF7 and select the form you would like to set up tracking for.<br/>
						If you set up tracking using the "Event Tracking" option in the CF7 form, you do not have to enter an ID. This is set automatically.<br/>
						Next you need a campaign name and an action name. These two values are required by Google Analytics.<br/>
						For example, the campaign for a contact form could be "Contact" and the "Request" action.', 'HelpPage Content', 'cf7-event-tracker' ); ?><p>
					<img src="<?php echo CF7ET_URL . 'img/howto/'.$user_lang.'/cf7_tracker_google_analytics_tab.jpg'; ?>" />
	
					<p>&nbsp;</p>
	
					<!--
						3.2. Individuelles JavaScript
					-->
					<h3><?php echo _x( '3.2. Individual JavaScript', 'HelpPage Title', 'cf7-event-tracker' ); ?></h3>
					<!--
						In manchen Fällen möchte man ein wenig mehr mit dem Kontaktformular anstellen, als eine reine Anfrage.<br/>
						Wenn du zum Beispiel eine Weiterleitung nach dem erfolgreichen Versand auf eine "Vielen Dank"-Seite erstellen möchtest, kannst du das im individuellen JavaScript einrichten.<br/>
						Ein paar Beispiele findest du im Hilfe-Reiter "JavaScript".
					-->
					<p><?php echo _x( 'In some cases you would like to do a little more with the contact form than a simple request.<br/>
						For example, if you want to create a redirect to a "Thank you" page after it has been successfully sent, you can set it up in individual JavaScript.<br/>
						You can find a few examples in the help tab "JavaScript".', 'HelpPage Content', 'cf7-event-tracker' ); ?></p>
					<img src="<?php echo CF7ET_URL . 'img/howto/'.$user_lang.'/cf7_tracker_custom_javascript_tab.jpg'; ?>" />
	
					<!--
						3.3. WordPress-System Tracking
					-->
					<h3><?php echo _x( '3.3. WordPress system tracking', 'HelpPage Title', 'cf7-event-tracker' ); ?></h3>
					<!--
						Dank dem Datenschutz kann in manchen Fällen kein Google Analytics zur Auswertung der Webseite verwedendet werden.<br/>
						Daher habe ich ein internes Tracking eingerichtet, um die jeweiligen Anfragen in deinem eigenen WordPress-System zu erfassen.<br/>
						Die Option "WordPress-Tracking" kannst du in den Plugin-Optionen bei Bedarf einschalten. Danach wird nur Datum von allen Anfragen in deinem System gesichert (Keine Informationen zum Besucher, wie IP-Adresse oder ähnliches).<br/>
						Durch diese Option bist du unabhängig von Google Analytics. Du kannst aber nachverfolgen, wie viele Anfragen über deine einzelnen Kontaktformulare gestellt werden.<br/>
						Wenn du das System-Tracking aktiviert hast, kannst du auf deinem WordPress-Dashboard ein Widget aktivieren, mit dem du jeder Zeit im Blick hast, wie viele Anfragen deine einzelnen Formulare erzeugt haben.
					-->
					<p><?php echo _x( 'Thanks to data protection, Google Analytics can in some cases not be used to evaluate the website.<br/>
						Therefore I have set up an internal tracking to record the respective requests in your own WordPress system.<br/>
						You can activate the "WordPress tracking" option in the plugin options if required. After that, only the date of all inquiries will be saved in your system (no information about the visitor, such as IP address or the like).<br/>
						With this option you are independent of Google Analytics. However, you can track how many inquiries are made through your individual contact forms.<br/>
						If you have activated system tracking, you can activate a widget on your WordPress dashboard, with which you can always see how many requests your individual forms generated.', 'HelpPage Content', 'cf7-event-tracker' ); ?></p>
					
					<p>&nbsp;</p>
	
					<!--
						3.4. HubSpot Integration
					-->
					<h3><?php echo _x( '3.4. HubSpot integration', 'HelpPage Title', 'cf7-event-tracker' ); ?></h3>
					<!--
						Dank der Integration der HubSpot-API kannst du ein Ticket für deine Anfragen in HubSpot automatisch erstellen lassen. Damit hast du deine Anfragen immer im Blick.<br/>
						Registriere dich dazu in HubSpot als Kundenbetreuer, um das CRM-System zu verwenden.<br/>
						In den "Einstellungen" findest du den Punkt "Integrationen > API-Schlüssel". Erstelle dir einen Schlüssel und trage ihn das Feld "Hubspot API Schlüssel" in den Optionen ein.<br/>
						Als nächstes kannst du für jedes Formular auswählen, ob zu den Anfragen ein Ticket erstellt werden soll und welche Informationen an HubSpot übertragen werden.<br/>
						Aktiviere das Feld "Hubspot Ticket bei Anfrage anlegen" und fülle die Felder "HubSpot Ticket Titel" und "HubSpot Ticket Beschreibung" aus.<br/>
						Mehr Informationen findest du im Hilfe-Reiter "HubSpot".
					-->
					<p><?php echo _x( 'Thanks to the integration of the HubSpot API, you can have a ticket automatically created for your inquiries in HubSpot. So you always have your requests in view.<br/>
						To do this, register in HubSpot as a customer advisor to use the CRM system.<br/>
						In the "Settings" you will find the item "Integrations > API key". Create a key and enter it in the field "Hubspot API key" in the options.<br/>
						Next, you can choose for each form whether a ticket should be created for the inquiries and what information will be transmitted to HubSpot.<br/>
						Activate the field "Create Hubspot Ticket on request" and fill in the fields "HubSpot Ticket Title" and "HubSpot Ticket Description".<br/>
						You can find more information in the help tab "HubSpot".', 'HelpPage Content', 'cf7-event-tracker' ); ?></p>
					<img src="<?php echo CF7ET_URL . 'img/howto/'.$user_lang.'/cf7_tracker_hubspot_tab.jpg'; ?>" />
	
					<p>&nbsp;</p>
	
					<!--
						4. Google Analytics Fehleranalyse
					-->
					<h3><?php echo _x( '4. Google Analytics error analysis', 'HelpPage Title', 'cf7-event-tracker' ); ?></h3>
					<!--
						Wenn du die Google Analytics Fehleranalyse in den Plugin-Optionen aktiviert hast, benachrichtigt dich das System, falls deine Formulare einen Fehler in den Google Analytics Feldern beinhalten.<br/>
						Das Plugin kann nicht prüfen, ob die Daten richtig in Google Analytics ankommen.<br/>
						Die Fehleranalyse zeigt dir nur, falls es zu möglichen Fehlern kommen kann.
					-->
					<p><?php echo _x( 'If you have activated the Google Analytics error analysis in the plugin options, the system will notify you if your forms contain an error in the Google Analytics fields.<br/>
						The plugin cannot check whether the data arrives correctly in Google Analytics.<br/>
						The error analysis only shows you if possible errors can occur.', 'HelpPage Content', 'cf7-event-tracker' ); ?></p>
	
					<p>&nbsp;</p>
	
					<!--
						5. JavaScript reduzieren
					-->
					<h3><?php echo _x( '5. Reduce JavaScript', 'HelpPage Title', 'cf7-event-tracker' ); ?></h3>
					<!--
						Ich empfehle diese Option zu aktivieren, falls du sehr viele Kontaktformulare erstellt hast.<br/>
						Dadurch wird der Tracking-Code im Frontend um ein Minimum reduziert, es kann aber gegebenenfalls zu kleineren Fehlern kommen.<br/>
						Beachte bitte, dass mit dieser Option nur Kontaktformulare getrackt werden können, die im Inhalts-Bereich deiner Seite eingefügt sind.<br/>
						Formulare, die in Widgets oder verschiedenen anderen Bereichen (Header oder Footer) in die PHP-Dateien deines Templates integriert wurden, können mit eingeschalteter JavaScript-Reduktion nicht mehr getrackt werden.
					-->
					<p><?php echo _x( 'I recommend activating this option if you have created a large number of contact forms.<br/>
						This reduces the tracking code in the frontend by a minimum, but there may be minor errors.<br/>
						Please note that this option can only track contact forms that are inserted in the content area of your page.<br/>
						Forms that have been integrated into the PHP files of your template in widgets or various other areas (header or footer) can no longer be tracked with JavaScript reduction enabled.', 'HelpPage Content', 'cf7-event-tracker' ); ?><br/>
	
					<p>&nbsp;</p>
	
					<!--
						6. Du hast einen Fehler gefunden?
					-->
					<h3><?php echo _x( '6. Did you find an error?', 'HelpPage Title', 'cf7-event-tracker' ); ?></h3>
					<!--
						Ein Plugin zu erstellen bedeutet sehr viel Arbeit und kontinuierliche Verbesserung.<br/>
						Teile mir Fehler über mein Kontaktformular mit, falls du einen gefunden haben solltest.<br/>
						Ich versuche den Fehler dann in einem folgenden Update zu beheben.
					-->
					<p><?php echo _x( 'Creating a plugin means a lot of work and continuous improvement.<br/>
						Let me know if you find one by using my contact form.<br/>
						I will then try to fix the error in a subsequent update.', 'HelpPage Content', 'cf7-event-tracker' ); ?></p>
	
					<p>&nbsp;</p>
	
					<!--
						Bitte denke daran die Einstellungen mit deinem Datenschutzbeauftragten zu klären.<br/>
						Ich übernehme keine Verantwortung für Datenschutz-Verstöße mit der Verwendung des CF7-Event-Tracker-Plugins.
					-->
					<p><?php echo _x( 'Please remember to clarify the settings with your data protection officer.<br/>
						I am not responsible for data protection violations when using the CF7 Event Tracker plugin.', 'HelpPage Content', 'cf7-event-tracker' ); ?></p>
	
					<p>&nbsp;</p>
	
				<?php
			}
			return ob_get_clean();
	
		}
	
		public static function cf7_event_tracker_help_javascript( $user_lang ) {
	
			ob_start();
			if( true ) {
	
				$slimstats_code =
				'SlimStat.ss_track( event, event_id, description );';
	
				$welcome_page_code =
				'setTimeout( function() {' . PHP_EOL .
				'	window.location.href = "https://www.example.com/thank-you";' . PHP_EOL .
				'}, 2000 );';
	
				?>
	
					<p>&nbsp;</p>
					<!--
						Individuelles JavaScript zu einem Formular hinzufügen
					-->
					<h1><?php echo _x( 'Add individual JavaScript to a form', 'HelpPage Title', 'cf7-event-tracker' ); ?></h1>
					<p>&nbsp;</p>
	
					<!--
						Mit dem CF7-Event-Tracker Plugin kannst du nicht nur deine Kontaktanfragen nachverfolgen.<br/>
						Für alles Weitere, was nach einer erfolgreichen Kontaktanfrage geschehen soll, gibt es ein Feld für ein individuelles JavaScript.
					-->
					<p><?php echo _x( 'With the CF7 Event Tracker plugin you can not only track your contact requests.<br/>
						For everything else that should happen after a successful contact request, there is a field for an individual JavaScript.', 'HelpPage Content', 'cf7-event-tracker' ); ?></p>
					
					<!--
						Hier findest du ein paar Anregungen, was du mit Contact Form 7 noch so alles anstellen kannst:
					-->
					<p><?php echo _x( 'Here are a few suggestions on what else you can do with Contact Form 7:', 'HelpPage Content', 'cf7-event-tracker' ); ?></p>
					
					<p>&nbsp;</p>
	
					<!--
						-
					-->
					<h3><?php echo _x( 'SlimStats Analytics', 'HelpPage Title', 'cf7-event-tracker' ); ?></h3>
					<!--
						SlimStats ist ein WordPress-Plugin, mit dem du Seitenaufrufe und Benutzer wie in Google Analytics nachverfolgen kannst.<br/>
						Der Unterschied ist, dass die Daten direkt in deiner Datenbank gesichert werden. Dadurch benötigst du keinen ADV mit Google für die DSGVO mehr.<br/>
						Mit einem kleinen Code-Snippet kannst du über das individuelle JavaScript ein SlimStats-Tracking zum Kontaktformular hinzufügen.
					-->
					<p><?php echo _x( 'SlimStats is a WordPress plugin that allows you to track pageviews and users as in Google Analytics.<br/>
						The difference is that the data is saved directly in your database. This means you no longer need an ADV with Google for the GDPR.<br/>
						With a small code snippet, you can add SlimStats tracking to the contact form using individual JavaScript.', 'HelpPage Content', 'cf7-event-tracker' ); ?></p>
					<textarea style="width: 100%; height: 80px;"><?php echo $slimstats_code; ?></textarea>
	
					<p>&nbsp;</p>
	
					<!--
						Weiterleitung auf eine "Vielen Dank"-Seite
					-->
					<h3><?php echo _x( 'Redirect to a "Thank you" page', 'HelpPage Title', 'cf7-event-tracker' ); ?></h3>
					<!--
						Mit einem kleinen Code kannst du den Besucher nach der Anfrage auf eine "Vielen Dank"-Seite weiterleiten lassen.<br/>
						Auf dieser Seite kannst du ihn noch einmal auf Angebote oder informative Beiträge auf deiner Webseite aufmerksam machen.
					-->
					<p><?php echo _x( 'With a small code, you can have the visitor redirected to a "Thank you" page after the request.<br/>
						On this page you can remind him again of offers or informative articles on your website.', 'HelpPage Content', 'cf7-event-tracker' ); ?></p>
					<textarea style="width: 100%; height: 80px;"><?php echo $welcome_page_code; ?></textarea>
	
					<p>&nbsp;</p>
	
					<!--
						PopUp mit weiteren Informationen
					-->
					<h3><?php echo _x( 'PopUp with further information', 'HelpPage Title', 'cf7-event-tracker' ); ?></h3>
					<!--
						Mit einem PopUp kannst du den schon anfragenden Besucher dazu auffordern etwas anderes auf deiner Webseite zu machen, bevor er sie verlässt.<br/>
						Das kann zum Beispiel eine Information zu einem neuen Produkt sein oder die Auffordungen am Newsletter teilzunehmen.<br/>
						Auf codepen.io findest du ein paar Beispiele, um ein PopUp nach deinen Wünschen zu gestalten.
					-->
					<p><?php echo _x( 'With a pop-up, you can ask the visitor who is already inquiring to do something else on your website before leaving.<br/>
						This can be, for example, information about a new product or the requests to participate in the newsletter.<br/>
						On codepen.io you can find a few examples to design a popup according to your wishes.', 'HelpPage Content', 'cf7-event-tracker' ); ?></p>
	
					<p>&nbsp;</p>
	
					<!--
						AJAX-Abfrage
					-->
					<h3><?php echo _x( 'AJAX-Query', 'HelpPage Title', 'cf7-event-tracker' ); ?></h3>
					<!--
						Durch eine AJAX-Anfrage auf ein PHP-Script deiner Webseite kannst du noch weitere Gimmicks zu deinem Kontaktformular hinzufügen.<br/>
						Du kannst zum Beispiel den aktuellen Warenkorb von WooCommerce oder Benutzer-Informationen nach einer Anfrage ausgeben lassen.<br/>
						Dazu benötigst du aber Kenntnisse in PHP und JavaScript.
					-->
					<p><?php echo _x( 'You can add more gimmicks to your contact form by making an AJAX request to a PHP script on your website.<br/>
						For example, you can have the current shopping cart output by WooCommerce or user information after a request.<br/>
						To do this, however, you need knowledge of PHP and JavaScript.', 'HelpPage Content', 'cf7-event-tracker' ); ?></p>
	
					<p>&nbsp;</p>
	
				<?php
			}
			return ob_get_clean();
	
		}
		
		public static function cf7_event_tracker_help_hubspot( $user_lang ) {
	
			ob_start();
			if( true ) {
				?>
	
					<p>&nbsp;</p>
					<!--
						HubSpot Ticket Integration
					-->
					<h1><?php echo _x( 'HubSpot Ticket Integration', 'HelpPage Title', 'cf7-event-tracker' ); ?></h1>
					<p>&nbsp;</p>
	
					<!--
						HubSpot ist ein "Customer Relationship Modell"-System.<br/>
						Mit dieser Plattform kannst du die Beziehungen zu deinen Kunden verwalten und Tasks zu den einzelnen Kunden notieren.
					-->
					<p><?php echo _x( 'HubSpot is a "customer relationship model" system.<br/>
						With this platform, you can manage relationships with your customers and record tasks for individual customers.', 'HelpPage Content', 'cf7-event-tracker' ); ?></p>
	
					<!--
						Zudem besitzt HubSpot ein sehr hilfreiches Ticket-System, mit dem du Anfragen deiner Kunden oder Interessenten nachverfolgen kannst.<br/>
						Mit den Tickets entgeht dir keine Rückmeldung zu einem potentiellen Kunden mehr.
					-->
					<p><?php echo _x( 'HubSpot also has a very helpful ticket system with which you can track inquiries from your customers or prospects.<br/>
						With the tickets you will no longer miss feedback on a potential customer.', 'HelpPage Content', 'cf7-event-tracker' ); ?></p>
	
					<!--
						Die Anfragen aus deinen Kontaktformularen können mit dem CF7-Event-Tracking-Plugin als Ticket an HubSpot übermittelt werden.
					-->
					<p><?php echo _x( 'Inquiries from your contact forms can be sent to HubSpot as a ticket using the CF7 event tracking plugin.', 'HelpPage Content', 'cf7-event-tracker' ); ?></p>
					
					<!--
						Dazu benötigst du zunächst einen kostenlosen CRM-Account auf HubSpot und einen API-Schlüssel, den du nach dem Login erstellen kannst.<br/>
						Schau in die Installations-Informationen im Hilfe-Panel, um zu erfahren, wie du den HubSpot-Schlüssel erstellen und in das Plugin hinzufügen kannst.
					-->
					<p><?php echo _x( 'To do this, you first need a free CRM account on HubSpot and an API key, which you can create after logging in.<br/>
						Check out the installation information in the help panel to learn how to create the HubSpot key and add it to the plugin.', 'HelpPage Content', 'cf7-event-tracker' ); ?></p>
	
					<!--
						Damit die Daten aus der Anfrage in HubSpot aufgenommen werden können, musst du die verschiedenen Platzhalter verwenden, die ich dir zur Verfügung gestellt habe.<br/>
						Die Felder für HubSpot findest du im Reiter "Event Tracking" im CF7-Kontaktformular oder in den Plugin-Optionen unter "CF7 Event Tracker > Formulare > HubSpot".
					-->
					<p><?php echo _x( 'In order for the data from the request to be included in HubSpot, you have to use the different placeholders that I have provided.<br/>
						You can find the fields for HubSpot in the "Event Tracking" tab in the CF7 contact form or in the plugin options under "CF7 Event Tracker > Forms > HubSpot".', 'HelpPage Content', 'cf7-event-tracker' ); ?></p>
	
					<!--
						Hier findest du alle Platzhalter, die du für deine HubSpot-Tickets verwenden kannst:
					-->
					<p><?php echo _x( 'Here you can find all placeholders that you can use for your HubSpot tickets:', 'HelpPage Content', 'cf7-event-tracker' ); ?></p>
	
					<style>
						.cf7-description-table tr th {
							text-align: left;
						}
					</style>
					<table class="cf7-description-table" border="1" cellspacing="0" cellpadding="5">
						<tr>
							<!--
								Platzhalter
							-->
							<th width="25%"><?php echo _x( 'Placeholder', 'HelpPage Label', 'cf7-event-tracker' ); ?></th>
							<!--
								Beschreibung
							-->
							<th width="50%"><?php echo _x( 'Description', 'HelpPage Label', 'cf7-event-tracker' ); ?></th>
							<!--
								Beispiele
							-->
							<th width="25%"><?php echo _x( 'Examples', 'HelpPage Label', 'cf7-event-tracker' ); ?></th>
						</tr>
						<tr>
							<th>%MM/DD/YYYY%</th>
							<!--
								Datum-Format 1: Monat - Tag - Jahr (Mit Slashes getrennt)
							-->
							<td><?php echo _x( 'Date format 1: month - day - year (separated by slashes)', 'HelpPage Label', 'cf7-event-tracker' ); ?></td>
							<td>%MM/DD/YYYY% -> 01/01/2020</td>
						</tr>
						<tr>
							<th>%DD/MM/YYYY%</th>
							<!--
								Datum-Format 2: Tag - Monat - Jahr (Mit Slashes getrennt)
							-->
							<td><?php echo _x( 'Date format 2: day - month - year (separated by slashes)', 'HelpPage Label', 'cf7-event-tracker' ); ?></td>
							<td>%DD/MM/YYYY% -> 01/01/2020</td>
						</tr>
						<tr>
							<th>%DD.MM.YYYY%</th>
							<!--
								Datum-Format 3: Tag - Monat - Jahr (Mit Punkte getrennt)
							-->
							<td><?php echo _x( 'Date format 3: day - month - year (separated by dots)', 'HelpPage Label', 'cf7-event-tracker' ); ?></td>
							<td>%DD.MM.YYYY% -> 01.01.2020</td>
						</tr>
						<tr>
							<th>%YYYY-MM-DD%</th>
							<!--
								Datum-Format 4: Jahr - Monat - Tag (Mit Bindestriche getrennt)
							-->
							<td><?php echo _x( 'Date format 4: year - month - day (separated by hyphens)', 'HelpPage Label', 'cf7-event-tracker' ); ?></td>
							<td>%YYYY-MM-DD% -> 2020-01-01</td>
						</tr>
						<tr>
							<th>%BLOGNAME%</th>
							<!--
								Mit diesem Platzhalter kannst du den Titel deines Blogs an HubSpot übertragen.
							-->
							<td><?php echo _x( 'With this placeholder you can transfer the title of your blog to HubSpot.', 'HelpPage Label', 'cf7-event-tracker' ); ?></td>
							<td>%BLOGNAME% -> Test-Blog</td>
						</tr>
						<tr>
							<th>%FORMTITLE%</th>
							<!--
								Der Name den du dem Contact Form 7 Formular gegeben hast.
							-->
							<td><?php echo _x( 'The name you gave the Contact Form 7 form.', 'HelpPage Label', 'cf7-event-tracker' ); ?></td>
							<td>%FORMTITLE% -> Contact Form 1</td>
						</tr>
						<tr>
							<th>[CF7-FIELD]</th>
							<!--
								Mit den eckigen Klammern kannst du ein Feld aus dem Kontaktformular an HubSpot übertragen, wie z.B. die E-Mail-Adresse oder den Namen.<br/>
								Schau dazu im Formular, welche Felder du dafür verwendest.
							-->
							<td><?php echo _x( 'With the square brackets you can transfer a field from the contact form to HubSpot, e.g. the email address or the name.<br/>
								Check the form to see which fields you are using.', 'HelpPage Label', 'cf7-event-tracker' ); ?></td>
							<td>[your-name] -> John Doe</td>
						</tr>
					</table>
	
					<p>&nbsp;</p>
	
				<?php
			}
			return ob_get_clean();
	
		}

	}
	
?>