<?php

    namespace CF7EventTracker;

    use \CPPluginCore\File;
    use \CPPluginCore\Loader;

    use CF7EventTracker\IncludeScripts;
    use CF7EventTracker\Pages\RegisterPages;
    use CF7EventTracker\Updater;
    use CF7EventTracker\Help\HelpPages;
    use CF7EventTracker\AJAX\AJAX;
    use CF7EventTracker\Dashboard\Dashboard;
    use CF7EventTracker\CF7Extension;
    use CF7EventTracker\PluginOptions;

    class PluginLoader extends Loader {

        function __construct( $plugin_path, $plugin_url ) {

            parent::__construct( $plugin_path, $plugin_url );

        }

        public function get_custom_backend_files( $priority ) {

            $settings_page = 'cf7_events';
            $forms_page = 'cf7_forms';
            $wpcf7_page = 'wpcf7';
    
            $files = array(
                'update'    => new File(
                    CF7ET_PATH . 'inc/global/Updater.php',
                    -1,
                    true,
                    function() {

                        $options = \get_option( 'cf7_ga_tracking' );
                        $settings = $options[ 'settings' ];
                        $license = \get_network_option( null, 'cf7et-license', '' );

                        $update = new Updater( CF7ET_PATH, CF7ET_INDEX );
                        $update->init_update(
                            array(
                                'license'		 => $license,
                                'remote'         => 'www.codepalm.de/updates/cf7-event-tracker-v2'
                            )
                        );

                    }
                ),
                'page_help'    => new File(
                    CF7ET_PATH . 'inc/global/backend/parts/HelpPages.php',
                    array(
                        $forms_page,
                        $settings_page
                    ),
                    true,
                    function() {

                        $help = new HelpPages();
                        $help->register_hooks();

                    }
                ),
                'fields'    => new File( 
                    CF7ET_PATH . 'inc/global/Fieldsets.php',
                    -1, 
                    true,
                    null
                ),
                'save_fields'   => new File( 
                    CF7ET_PATH . 'inc/global/Save.php',
                    -1, 
                    true,
                    null
                ),
                'plugin_options'    => new File(
                    CF7ET_PATH . 'inc/global/backend/PluginOptions.php',
                    -1,
                    true,
                    function() {

                        \add_action( 'admin_menu', function() {

                            $plugin_options = new PluginOptions( 'cf7_events' );
                            $plugin_options->register_hooks( 'events', "CF7 Events", _x( "Settings", 'Options Label', 'cf7-event-tracker' ), false, CF7ET_URL . 'img/icon.png', 90 );

                        }, 10 );

                    }
                ),
                'sidebar'       => new File(
                    CF7ET_PATH . 'inc/global/backend/parts/Sidebar.php',
                    -1, 
                    true,
                    null
                ),
                'scripts'       => new File(
                    CF7ET_PATH . 'inc/global/IncludeScripts.php',
                    -1,
                    false,
                    function() {

                        $include = new IncludeScripts();
                        $include->register_hooks();

                    }
                ),
                'curl'       => new File(
                    CF7ET_PATH . 'inc/global/cURLHandler.php',
                    -1,
                    false,
                    null
                ),
                'admin_error'       => new File(
                    CF7ET_PATH . 'inc/global/AdminError.php',
                    -1,
                    false,
                    null
                )
            );
            return $files;
    
        }

        public function get_custom_frontend_files( $priority ) {

            $files = array(
            );
            return $files;
    
        }

    }

?>