WP Plugin AddOn Scripts
=======================

Dieses Programm wird als Core für die Erstellung von WordPress-Plugins verwendet.  
In der Datei `composer.json` des [WP-Plugin-Samples](#) werden diese Komponenten automatisch installiert.


Das Publish-Script
------------------

Das Publish-Script wurde erstellt, um den Veröffentlichungs-Prozess eines Plugin-Updates zu automatisieren.  
Durch die einmalige Konfiguration benötigst du nur noch eine Zeile Code, um das Update für die Webseiten bereit zu stellen. 
**Wichtig:** Das Plugin updated sich nicht automatisch. Nachdem das neue Update auf dem Update-Server bereitgestellt wurde, muss das Plugin im Kunden-Projekt aktualisiert werden. Mehr dazu später. 

### __Ablauf des Publish-Scripts__

 1. Erhalte Plugin-Variablen von `$BASEDIR/bin/plugin-conf.sh`
 2. Erstelle das CSS aus SCSS in `bin/start-less.sh` in `$BASEDIR/css/scss`
 3. Starte `composer update`
 4. Prüfe ob alles nach Git committed und gepushed wurde
 5. Erstelle `plugin.json` in `bin/create-plugin-json.sh`
 6. Erhalte aktuellen Branch-Namen für das ZIP-Suffix
 7. Lese das SSH-Passwort vom Benutzer und teste die Verbindung
 8. Erstelle den Build-Ordner `$BASEDIR/build/`
 9. Erstelle die ZIP-Datei des Plugins in `$BASEDIR/build/`
10. Erstelle den Remote-Ordner wenn es nicht existiert
11. Übertrage die ZIP-Datei zum Remote-Server
12. Übertrage die `plugin.json` zum Remote-Server
13. Starte den Cleanup-Prozess um `$BASEDIR/build` zu löschen


### __Verwendung des Shell-Scripts__

1. Stelle sicher, dass alle Änderungen zu Git hochgeladen wurden (Das Script erinnert dich in **Step 4** daran)
2. Stelle sicher, dass du das SCSS kompiliert hast und das keine Fehler vorhanden sind (Das Script erinnert dich in **Step 2** daran)
3. Stelle sicher, dass du dich im Stamm-Verzeichnis deiner Plugins befindest
4. Rufe das Script im Terminal mit folgendem Befehl auf: `sh bin/publish-tag.sh`
5. Warte, bis das Programm bei **Step 7** angekommen ist und gebe dann das SSH-Passwort ein
6. Warte, bis das Skript die Dateien erstellt und veröffentlicht hat

Danach solltest du im angegebenen Remote-Server einen Ordner mit dem Namen deines Plugins finden.  
Darin enthalten ist die neu erstellte ZIP-Datei deines Plugins und die neue Datei `plugin.json`.


### __Vorbereitung in deinem Plugin__

Bevor du das Publish-Script verwenden kannst, benötigst du in deinem Plugin ein paar Konfigurations-Dateien.  
Solltest du das [WP-Plugin-Sample](#) als Grundlage für dein Plugin verwenden, hast du diese Dateien bereits im Projekt. Du musst aber die einzelnen Variablen innerhalb der Dateien anpassen. 

Folgende Dateien werden für das Script benötigt (Ausgang ist das Root-Directory **deines** Plugins)
1. `/bin/plugin-conf.sh`
2. `/bin/plugin-data.sh`

Optional kannst du im Ordner `/bin` eine Datei `publish-tag.sh` mit folgendem Inhalt anlegen: 
```bash
sh vendor/codepalm/wp-plugin-core/bin/publish-tag.sh
```
Durch diese Zeile erstellst du eine Verknüpfung zur `publish-tag.sh` im WP-Plugin-Addon Verzeichnis. Das macht die Eingabe im Terminal einfacher.

Als nächstes musst du die Variablen in den Dateien `/bin/plugin-conf.sh` und `/bin/plugin-data.sh` befüllen bzw. austauschen.  

**`bin/plugin-conf.sh`:**
```bash
# Der eindeutige Plugin-Name ohne Leerzeichen, Sonderzeichen nur Lowercase-Letters
PLUGIN_NAME="sample-plugin"
# Der Benutzer-Name des SSH-Zugangs
REMOTE_USER="remote_user"
# Der Remote-Server für den SSH-Zugang
REMOTE_HOST="localhost"
# Der Pfad zum Verzeichnis des Plugin-Ordners in dem sich die Updates befinden
REMOTE_PATH="updates/sample-project"
```
**Wichtig:** Trage nicht das SSH-Passwort in eine dieser Dateien, da dies eine Sicherheitslücke darstellen kann!

**`bin/plugin-data.sh`:**
```bash
BASEDIR=$(pwd)

# === Authentication ===
HT_USER="your-username"  
HT_PASS="your-passphrase"  

# === Plugin Globals ===
# Der Name des Plugins in Volltext (Groß/Kleinschreibung, Sonderzeichen, Zahlen, Leerzeichen erlaubt)
JSON_PLUGIN_NAME="Sample-Plugin"
# Die Version des Plugins. Beachte das Schema von Semver.org
JSON_PLUGIN_VERSION="1.2.3"
# Der absolute Pfad zur neuesten ZIP-Datei des Updates
JSON_PLUGIN_DOWNLOAD_URL="https://example.de/updates/sample-project/sample-project.zip"

# === Plugin Creator ===
# Die Homepage des Plugins
JSON_PLUGIN_HOMEPAGE="https://www.example.de/"
# Der Haupt-Ersteller des Plugins
JSON_AUTHOR_NAME="Dennis Artinger"
# Der Pfad zur Autoren-Seite (Kann auch deine eigene Webseite oder Blog sein)
JSON_AUTHOR_URL="https://www.codepalm.de/"

# === Plugin Update Notices ===
# Nicht ändern! Das aktuelle Datum des Updates
JSON_PLUGIN_LAST_UPDATE=$(date +'%Y-%m-%d %H:%M:%S')
# Mindest WordPress-Version
JSON_PLUGIN_MIN_VERSION="4.9"
# Getestet bis ... WP-Version
JSON_PLUGIN_MAX_VERSION="5.3"
# Update-Notiz
JSON_UPDATE_NOTICE="Here's why you should upgrade..."

# === Plugin Descriptions ===
# Nicht ändern! Diese Variablen werden automatisch aus den einzelnen Dateien entnommen. Mehr dazu später.
# Get README.md, Parse to HTML, Remove newslines and tabs
JSON_PLUGIN_DESCRIPTION=$(echo $(sh $BASEDIR/vendor/codepalm/wp-plugin-core/bin/markdown.sh $BASEDIR/README.md) | tr -d '\n\r\t' | tr '"' "'")
# Get INSTALL.md, Parse to HTML, Remove newslines and tabs
JSON_PLUGIN_INSTALLATION=$(echo $(sh $BASEDIR/vendor/codepalm/wp-plugin-core/bin/markdown.sh $BASEDIR/INSTALL.md) | tr -d '\n\r\t' | tr '"' "'")
# Get CHANGELOG.md, Parse to HTML, Remove newslines and tabs
JSON_PLUGIN_CHANGELOG=$(echo $(sh $BASEDIR/vendor/codepalm/wp-plugin-core/bin/markdown.sh $BASEDIR/CHANGELOG.md) | tr -d '\n\r\t' | tr '"' "'")

# === Plugin Images ===
# Pfad zum High-Res-Icon
JSON_PLUGIN_ICON_HIGH="http://w-shadow.com/files/external-update-example/assets/icon-256x256.png"
# Pfad zum Low-Res-Icon
JSON_PLUGIN_ICON_LOW="http://w-shadow.com/files/external-update-example/assets/icon-128x128.png"
# Pfad zum High-Res-Banner
JSON_PLUGIN_BANNER_HIGH="http://w-shadow.com/files/external-update-example/assets/banner-1544x500.png"
# Pfad zum Low-Res-Banner
JSON_PLUGIN_BANNER_LOW="http://w-shadow.com/files/external-update-example/assets/banner-772x250.png"
```


### __Plugin-Informationen__

Die Plugin-Informationen aus den Variablen `JSON_PLUGIN_DESCRIPTION`, `JSON_PLUGIN_INSTALLATION` und `JSON_PLUGIN_CHANGELOG` werden automatisch aus den verschiedenen md-Dateien generiert.  
Stelle sicher, dass die Dateien `README.md`, `INSTALL.md` und `CHANGELOG.md` in deinem Stamm-Verzeichnis existieren und regelmäßig gepflegt werden!  

Die md-Dateien werden automatisch in valides HTML gewandelt und in die Datei `plugin.json` eingefügt.  
**Stelle dringend sicher, dass du weißt was du tust, wenn du die md-Dateien nicht verwenden möchstest!**


### __Das Plugin beim Kunden aktualisieren__

Sobald du das Update auf den Update-Server bereitgestellt hast, musst du es noch auf dem Kunden-Projekt installieren.  
Melde dich dazu im WordPress-System des Kunden an und navigiere in der linken Sidebar zu "Plugins".  
Sollte das Plugin noch nicht festgestellt haben, dass ein neues Update zur Verfügung steht, kannst du in der Spalte des Plugins auf den Link "Nach Updates suchen" klicken.  
Als letztes musst du das Plugin-Update nur noch in WordPress starten.  

---
---


PHP-Klassen
-----------

Es gibt einige Parent-Klassen, die du als Grundlage für dein Plugin verwenden kannst.  
Nachfolgend wird beschrieben, wie du diese Klassen in deinem eigenen Plugin verwenden kannst.  

**Wichtig:** Die Vendor-Klassen verwenden alle den Namespace `CPPluginCore`. Verwende in deinem Plugin entweder den gleichen Namespace oder füge die entsprechenden Klassen durch `use \CPPluginCore\CLASS` in deine PHP-Dateien hinzu.  


### __Loader und Files__

_**Pfad:** /loader/Loader.php_

Die Klasse `Loader` lädt alle Plugin-Dateien in das WordPress-System.  
Erstelle ein Verzeichnis `/inc/global` in deinem Plugin und Erstelle die Datei `PluginLoader.php`.  

Der Loader besteht aus 2 Funktionen: `get_custom_backend_files` und `get_custom_frontend_files`.  
Beide Funktionen beinhalten eine Array, die die individuellen PHP-Dateien lädt und initialisiert.  

Die Array `$custom_files` besteht wiederum aus 2 Arrays: `high` und `low`.  
Durch diese Handler können Dateien mit unterschiedlicher priorisierung geladen werden.  

Die Priorisierung baut sich folgendermaßen auf:  
1. Standard-Funktionen des WP-Plugin-AddOns mit der Priorität `high`
2. Individuelle Funktionen des Plugins mit der Priorität `high`
3. Standard-Funktionen des WP-Plugin-AddOns mit der Priorität `low`
4. Individuelle Funktionen des Plugins mit der Priorität `low`

Durch die Übergabe des Parameters `$priority` in den beiden Funktionen, kann die entsprechende Array `high` oder `low` geladen werden.  

```php
class PluginLoader extends Loader {

    protected function get_custom_backend_files( $priority ) {

        // In dieser Funktion werden alle individuellen PHP-Skripte/-Klassen geladen, die für das WP-Backend zuständig sind.
        $custom_files = array(
            // Die Array "high" wird mit einer höheren Priorität behandelt, wie "low"
            'high' => array(
                // Die Klasse "File" wird nur für den Loader benötigt. Sie prüft, ob Dateien existieren und lädt diese in das Projekt.
                'plugin_init'    => new File( 
                    $this->plugin_path . 'inc/global/PluginInitial.php',
                    -1,
                    true, // "true" wenn die Datei als "required", "false" wenn sie als "include" geladen werden soll
                    function() {

                        // Dies ist eine Callback-Funktion, die ausgeführt wird, sobald die Datei "PluginInitial.php" geladen wurde

                        // "PluginInitial" ist eine individuelle Klasse, um Initiale Algorithmen vor der Ausgabe zu starten. z.B. die Verarbeitung von $_POST
                        $include = new PluginInitial();

                        // Die Klasse "PluginInitial" enthält Hooks, die über die Funktion "add_hooks" aufgerufen werden müssen
                        $include->add_hooks();

                    }
                )
            ),
            'low' => array(
                'plugin_include'    => new File(
                    $this->plugin_path . 'inc/global/PluginIncludeScripts.php',
                    -1,
                    true,
                    null    // Sollte in diesem Parameter "null" stehen, wird kein Callback nach dem Laden der Datei ausgeführt
                )
            )
        );
        
        return $custom_files[ $priority ];
        
    }

    protected function get_custom_frontend_files( $priority ) {

        // Diese Dateien werden nur im Frontend von WP geladen 
        // Der Aufbau ist identisch mit "get_custom_backend_files()".

    }
    
}
```


### __Fehlermeldungen__

_**Pfad:** /globals/AdminError.php_

Neue Fehlermeldungen können an einer beliebigen Stelle mit `AdminError::get_error( $type )` zur Pipe hinzugefügt werden.  
Im WP-Backend werden die Fehlermeldungen oben angezeigt, wenn welche existieren.  
`$type` ist der Code für die Status-Meldung. Folgende Codes sind bereits im System enthalten: 
```
Zur Zeit sind noch keine richtigen Fehlermeldungen definiert. 
Bitte warte auf ein entsprechendes Update.
```

Da die Klasse bereits vom `Loader` hinzugefügt wird, kann sie direkt verwendet werden.  
Solltest du eigene Fehlermeldungen zum System hinzufügen wollen, kannst du das mit einer entsprechenden Klasse in deinem Projekt machen.  
```php
class PluginErrorCodes {

    function __construct() {}

    public function add_filters() {

        add_filter( 'custom_error_codes', array( $this, 'add_custom_error_codes' ), 10, 2 );

    }

    public function add_custom_error_codes( $msg, $type ) {

        switch( $type ) {

            case 501:
                return __(
                    'Individueller Fehler',
                    'cp-plugin-core'
                );

            default: 
                return null;
            
        }

    }

}
```

Beachte, dass diese Klasse vom individuellen `Loader` geladen werden muss. Es wird eine hohe Priorität (`high`) empfohlen.  
Nachdem ein Objekt aus der Klasse erstellt wurde, muss die Funktion `add_filters` gestartet werden.  

Im Loader sieht das wie folgt aus:  
```php
$custom_files = array(
    'high' => array(
        'plugin_errors'    => new File( 
            $this->plugin_path . 'inc/global/PluginInitial.php',
            -1,
            true,
            function() {

                $include = new PluginErrors();
                $include->add_filters();

            }
        )
    ),
    'low' => array(
        // ...
    )
);
```

Beachte, dass die Fehler-Meldungen nur im Backend funktionieren. Füge die individuellen Fehlermeldungen also in der Funktion `get_custom_backend_files` hinzu.


### __Update-Informationen__

_**Pfad:** /globals/Credentials.php_

Wenn dein Plugin Update-Fähig werden soll, benötigst du eine Klasse, um die Update-Informationen zu hinterlegen.  
Erstelle eine Datei im Ordner `/inc/global/` und nenne sie `PluginCredentials.php`.  

Trage folgenden Code ein und tausche die entsprechenden Variablen aus, um eine Verbindung mit dem Update-Server herzustellen: 
```php
class PluginCredentials extends Credentials {

    public static function get_credentials() {

        $credentials = array(
            'plugin_slug'		=> 'sample-plugin',             // Verwende hier den Slug deines Plugins wie in der Stamm-Datei
            'ht_user'           => 'sample-user',               // Trage hier den Benutzer des htaccess-Schutz für die plugin.json ein
            'ht_passwd'         => '123456',                    // Trage hier das Passwort des htaccess-Schutz für die plugin.json ein
            'ht_remote'         => 'example.de/updates/sample'  // Der absolute Pfad ohne Protokoll zum Plugin-Verzeichnis
        );
        return $credentials;

    }

}
```

Es ist wichtig, die Klasse `PluginCredentials` zu benennen. Beim Loading-Prozess wird nach dieser Klasse gesucht und versucht die statische Funktion `get_credentials()` zu verwenden.  
Sollte die Klasse nicht existieren, kann kein Update gestartet werden. Zudem findest du im WordPress-Backend einen entsprechenden Fehler.  

Stelle sicher, dass auf deinem Server eine gültige htaccess-Datei mit einem Passwort-Schutz für die Datei `plugin.json` vorliegt.  
Die `.htaccess` wird in das Stamm-Verzeichnis des Plugin-Update-Ordner gelegt. Der htaccess-Schutz kommt an eine andere Stelle (Nimm Kontakt mit [Dennis Artinger](mailto:d.artinger@codepalm.de) auf, um zu erfahren, wo die Passwort-Datei liegt).  

So kannst du deine `.htaccess`-Datei aufbauen:  
```apacheconf
<Files plugin.json>
	AuthName "Username and password required"
	AuthUserFile /path/to/.htpasswd
	AuthType Basic
	Require valid-user
</Files>
```

**Hinweis:** Es wird aktuell nach einer Möglichkeit gesucht, die ZIP-Dateien ebenfalls zu schützen. Bitte achte auf Updates in dieser README-Datei!


### __Update__

_**Pfad:** /globals/Updater.php_

Das Update-Skript arbeitet autark. Alle notwenigen Einstellungen, die du vornehmen musst, findest du unter "Update-Informationen".  
Sollte es Änderungen zum Updater geben, findest du diese in der [CHANGELOG.md](./CHANGELOG.md) oder unter "Update-Informationen".



### __Styles und Scripts__

_**Pfad:** /globals/IncludeScripts.php_

Das Plugin-AddOn ladet schon automatisch ein paar wenige Inhalte, um richtig zu funktionieren.  
CSS-Dateien werden über dein eigenes Plugin geladen. Das funktioniert über einen SCSS-Parsing-Prozess.  

Das `WP-Plugin-Sample` enthält bereits alle notwenigen Konfigurationen, um die Backend- und Frontend-Style zu deinem eigenen Plugin hinzuzufügen.  
Der SCSS-Parser wird automatisch beim Veröffentlichungs-Prozess durch `publish-tag.sh` gestartet. Du kannst aber die Datei `start-less.sh` verwenden, um das SCSS manuell in CSS zu wandeln.  
In der `start-less.sh` sind bereits alle wichtigen Konfigurationen enthalten, um einen sauberen CSS-Code an die richtigen Stellen zu platzieren.  

Du kannst aber dennoch dein eigenes CSS oder Drittanbieter-Codes über eine entsprechende Klasse laden lassen.  
Erstelle dazu im Ordner `/inc/global/` eine Datei `PluginIncludeScripts.php` und binde diese, wie in **Loader** beschrieben in die Priorität `high`.  

So sollte deine Klasse `PluginIncludeScripts` aufgebaut werden:  
```php
class PluginIncludeScripts {

    public function register_hooks() {
        
        // Die nachfolgenden Hooks sollten so verwendet werden, auch wenn mache Funktionen leer bleiben.

        // Du kannst weitere Funktionen defnieren, um eine Abhängigkeit nach Post-Type zu generieren.
        // Abfrage erfolgt durch $post->post_type in der entsprechenden Funktion, nicht in "register_hooks"!
        // (Abfrage in "register_hooks" wird nicht funktionieren, da WP an dieser Stelle noch nicht geladen ist)

        add_action( 'wp_enqueue_scripts', array( $this, 'include_frontend_scripts' ) );
        add_action( 'wp_enqueue_scripts', array( $this, 'include_frontend_styles' ) );

        add_action( 'admin_enqueue_scripts', array( $this, 'include_backend_scripts' ) );
        add_action( 'admin_print_styles', array( $this, 'include_backend_styles' ) );

    }

    // Frontend
    public function include_frontend_scripts() {

        // JavaScripts für Frontend
        wp_register_script( 'cp-plugin-core_script', $this->plugin_url . 'js/script.js' );
        wp_enqueue_script( 'cp-plugin-core_script' );

    }

    public function include_frontend_styles() {

        // CSS für Frontend
        wp_register_style( 'fontawesome', $this->plugin_url . 'css/font-awesome.min.css' );
        wp_enqueue_style( 'fontawesome' );

    }

    // Backend
    public function include_backend_scripts() {
        // JavaScripts für Backend
    }

    public function include_backend_styles() {
        // CSS für Backend
    }

}
```


### __Shortcodes__

_**Pfad**: /globals/Shortcode.php_

Um einen neuen Shortcode zu erstellen, benötigst du zunächst eine Klasse, die sich um das einladen der Shortcodes kümmern wird.  
Erstelle dazu eine neue Datei `PluginShortcodes.php` im Ordner `/inc/global/`.  

Füge in diese Datei nun folgenden Inhalt ein: 
```php
class PluginShortcodes {

    function __construct() {}

    public function load_shortcodes() {

        // Lade hier alle notwenigen Shortcode-Dateien rein. 
        require_once( $this->plugin_path . 'inc/shortcodes/DefaultShortcode.php' );

    }

    public function add_shortcodes() {

        // Der jeweilige Shortcode wird in einer Variable deklariert.
        $default_shortcode = new DefaultShortcode();

        // Die Funktion "add_hook()" der Shortcode-Klasse wird hier ausgeführt, um den Shortcode zum System hinzuzufügen
        $default_shortcode->add_hook();

    }

}
```

Nun erstellst du eine neue Datei `DefaultShortcode.php` im Ordner `/inc/shortcodes/` mit folgendem Inhalt:  
```php
class LoginMask extends Shortcode {

    function __construct() {
        
        $this->shortcode_handler = 'default_shortcode';

    }

    public function shortcode_callback( $attr, $content="" ) {
        
        // Die beiden Werte "color" und "height" werden automatisch mit einem Default-Wert "FFFFFF" und "0" bestückt
        // Durch die Funktion "extract()" kann eine assoziative Array automatisch zu entsprechende Variablen geändert werden -> $color und $height
        // Vorsicht: Die Attribute dürfen bei der Verwendung von "extract()" nur gültige Zeichen besitzen!
        //      -> Kleinbuchstaben, Zahlen und Unterstriche sind erlaubt.
        //      -> Kein Minus/Trennstrich, Leerzeichen und keine Sonderzeichen! Auch wenn diese in einer assoc. Array erlaubt sind.
        //      -> Zahlen sollten nicht als erstes Zeichen vorkommen.
        extract(
            shortcode_atts(
                array(
                    'color' => 'FFFFFF',        // Erweitere diese Array, um eigene Variablen/Attribute zu defineren.
                    'height' => '0'             // Bearbeite die Werte, um einen Default-Wert festzulegen, wenn das Attribut leer ist.
                ),
                $attr                           // Übergebe hier die Variable "$attr" aus dem Parameter der Funktion
            )
        );
        
        // Hier kommt deine Ausgabe hin.
        // Splitte deine Funktion in Mehere, um eine bessere übersicht zu erhalten.
        // Achte bei einem Funktionsaufruf darauf, dass du sie mittels $this->FUNKTIONSNAME() aufrufen musst.
        ob_start();
        ?>
            <p>Hello World!</p>
        <?php
        return ob_get_clean();
        
    }

}
```

Alle notwenigen Funktionen zum einbinden des Shortcodes werden von der PHP-Klasse `Shortcode` vorgenommen, die vom WP-Plugin-Addon stammen.  
Du musst dich nur noch um die Ausgabe des Shortcodes kümmern.  

Der Beschriebene Default-Shortcode kann durch folgenden Code im Content-Bereich einer WP-Seite aufgerufen werden: `[default_shortcode]`  
Den Shortcode-Aufruf kannst du durch die Variable `$this->shortcode_handler` im Konstruktur steuern. 
Beachte, dass der Wert `shortcode_handler` eindeutig sein sollte. Er darf in keinem anderen Shortcode vorkommen. 

Auf diese Weise kannst du so viele Shortcodes hinzufügen, wie du benötigst.  
Es ist angedacht, ein paar Standard-Shortcodes zu erstellen, die man optional im eigenen Plugin einladen kann.  

Mit den Parametern `$attr` und `$content` können die Attribute und der Inhalt des Shortcodes ausgelesen werden.  
Um Attribute in deinem Shortcode zu verwenden kannst du der Anleitung im Code-Snippet (oben) folgen.  
Zudem findest du im Code-Snippet einen Vorschlag zur Verwendung des assoziativen Array's "$attr".  

Durch die Wordpress-Funktion `shortcode_atts()` kannst du Default-Werte für deine Variablen definieren.  
Optional kannst du die PHP-Funktion `extract()` verwenden, um aus der assoziativen Array einzelne Variablen zu deklarieren. Das macht die Handhabung im Code etwas einfacher, jedoch wird in ein paar Foren Beschrieben, dass die `extract()`-Funktion unsicher ist.  
Bisher habe ich aber nur gute Erfahrungen mit der Funktion gemacht.  

**Hinweis**: Solltest du für deinen Shortcode spezielles CSS verwenden, solltest du ein entsprechendes SCSS-Template im Ordner `/css/scss/frontend/elements/shortcodes/` erstellen. Der Dateiname der SCSS-Datei sollte mit dem Plugin übereinstimmen. Zudem musst du das Template durch einen `@import` in die Datei `main.scss` im Ordner `/css/scss/` hinzufügen.


### __Plugin-Optionen__

_**Pfad**: /globals/backend/Options.php_

Plugin-Optionen sind Seiten im Backend, auf der Redakteure oder Administratoren Einstellungen vornehmen können.  
Um eine solche Seite zu erstellen, benötigst du zunächst eine neue Datei `PluginOption.php` im Verzeichnis `/inc/global/backend/`.  

Folgenden Code kannst du als Standard verwenden:  
```php
class PluginOption extends Options {
    
    // Im Content findet man die Einstellungen, die der Admin/Redakteur vornehmen kann, um Funktionen des Plugins zu steuern
    public function get_content() {

        ob_start();
        ?>
            <p><?php echo __( 'The Content', 'cp-plugin-core' ); ?></p>
        <?php
        return ob_get_clean();

    }

    // Im Header wird der Titel der Seite ausgegeben. Das kann zum Beispiel "Plugin-Optionen" sein
    // Ein Sub-Titel oder ganz andere Informationen können natürlich auch platziert werden
    public function get_header() {

        ob_start();
        ?>
            <h1><?php echo __( 'The Header/Title', 'cp-plugin-core' ); ?></h1>
        <?php
        return ob_get_clean();

    }

    // Der Footer kann z.B. für Rechtstexte verwendet werden (Made by Codepalm)
    public function get_footer() {

        ob_start();
        ?>
            <p><?php echo __( 'The Footer', 'cp-plugin-core' ); ?></p>
        <?php
        return ob_get_clean();

    }

    // In der Sidebar kannst du Informationen, Hilfetexte oder Werbung für unsere Produkte platzieren
    // Später soll es die Möglichkeit geben, die Sidebar auszuschalten
    public function get_sidebar() {

        ob_start();
        ?>
            <p><?php echo __( 'The Sidebar', 'cp-plugin-core' ); ?></p>
        <?php
        return ob_get_clean();

    }

}
```

Diese Datei wird über den `Loader` in der Funktion `get_custom_backend_files()` in der Priorität `high` gesetzt.  
Hier wird auch definiert, ob es sich bei den Plugin-Optionen um eine Haupt- oder Unter-Seite handelt. 
```php
protected function get_custom_backend_files( $priority ) {

    $custom_files = array(
        'high' => array(
            // ... Hier stehen alle anderen Elemente der assoc. Array.
            'plugin_options'    => new File(
                $this->plugin_path . 'inc/global/backend/PluginOption.php',
                -1,
                true,
                function() {

                    // Wichtig: Haupt-Menüs immer mit der "add_action( 'wp_loaded' )" verwenden
                    //          Sub-Menüs immer mit "add_action( 'admin_menu' )" verwenden

                    // Haupt-Menü:
                    add_action( 'wp_loaded', function() {

                        $plugin_option = new PluginOption(
                            'plugin_addon_main'            // Die ID der Unterseite. Das kann z.B. "docu" oder "members" sein. Muss einzigartig sein!
                        );
                        $plugin_option->register_hooks(
                            'plugin',                   // Noch nicht relevant
                            "My Plugin Options",                // Der Haupt-Titel in der Sidebar
                            "Einstellungen",            // Der Seiten-Titel des Menüs
                            false,                      // false = Ist Hauptmenü
                            'dashicons-admin-generic',  // Das Icon für den Menüpunkt
                            90                          // Die Position des Menüs
                        );

                    });

                    // Unter-Menü
                    add_action( 'admin_menu', function() {

                        $plugin_option_sub = new PluginOption(
                            'plugin_addon_sub',            // ID des Unter-Menüs
                            'plugin_addon_main'            // ID des Haupt-Menüs
                        );
                        $plugin_option_sub->register_hooks(
                            'submenu',                  // Noch nicht relevant
                            "Submenü",                  // Der Haupt-Titel in der Sidebar
                            "Submenü",                  // Der Seiten-Titel des Menüs
                            true,                       // true = Ist Untermenü
                            'dashicons-admin-generic'   // Für Sub-Menü irrelevant - Kann entfernt werden
                        );

                    });


                }
            )
            // ... Hier können noch mehr Elemente eingefügt werden.
        ),
        'low' => array(
            // Hier musst du nichts ändern
        )
    );
    
    return $custom_files[ $priority ];
    
}
```

Unter-Menüs können keine Icons besitzen. Es rentiert sich also nicht bei solchen eines zu verwenden.  
Für ein Haupt-Menü kannst du dir entweder eines aus den [Dashicons](https://developer.wordpress.org/resource/dashicons/) (wie im Beispiel) aussuchen, oder ein PNG zum Projekt hinzufügen und dieses laden.  


Formulare oder andere Eingabe-Elemente sollten als eigene `protected function` in der Klasse eingefügt und im "Content" aufgerufen werden.  
Hier ein einfaches Beispiel für eine Eingabe-Maske:  
```php
class PluginOption extends Options {

    // ... Hier kommen die Funktionen "get_header()", "get_footer()" und "get_sidebar()" rein

    public function get_content() {

        ob_start();
        
        echo $this->get_custom_form();

        return ob_get_clean();

    }

    protected function get_custom_form() {

        ob_start();
        ?>
            <form action="<?php /* Current Page */ ?>" method="POST">
                <?php
                    echo $this->get_input_field( 'text', 'username' );
                    echo $this->get_input_field( 'password', 'password' );
                ?>
            </form>
        <?php
        return ob_get_clean();

    }

    protected function get_input_field( $type, $id ) {

        ob_start();
        ?>
            <input type="<?php echo $type; ?>" id="<?php echo $id; ?>" name="<?php echo $id; ?>" value="" />
        <?php
        return ob_get_clean();

    }

}
```


### __Upcomming Features__

Es werden in der Zukunft weitere Funktionen für dieses Script hinzugefügt.  
Solltest du Ideen oder Wünsche für Funktionen haben, kannst du mir gerne schreiben: [Dennis Artinger](mailto:d.artinger@codepalm.de)

Folgende Features sind aktuell in der Pipe:  
1. Ich überlege die Sidebar über eine globale Stelle (REST-API oder ähnliches) zu steuern, um unseren Kunden auf Neuigkeiten und Produkte aufmerksam zu machen. Dadurch muss nicht jeder einzelne Entwickler die Sidebar befüllen. Die Inhalte werden dann automatisch von einem externen System befüllt. Als Entwickler kann man dann nur noch entscheiden, ob diese Inhalte angezeigt werden sollen, oder nicht.
2. Die ZIP-Dateien der Updates sollen von einer eigenen Subdomain verwaltet werden. Mein Plan ist es die Subdomain `wpupdate.codepalm.de` zu erstellen, auf dem nur Updates hochgeladen werden. (Es soll dann die Ordner-Strukturen `wp/plugins` und `wp/themes` geben. Vielleicht werden in Zukunft auch Plugins/Extensions für andere Content Management Systeme erstellt)
3. Die ZIP-Dateien der Updates müssen noch besser geschützt werden. Aktuell wird nur die `plugin.json` per htaccess geschützt. Wenn ich einen htaccess-Schutz auf die ZIP-Dateien anwende, kann WordPress die Updates aber nicht mehr herunterladen. Es muss eine Alternative geplant und umgesetzt werden.
4. Ich hatte schon häufig das Problem, dass ich einen eigenen Algorithmus aufbauen musste, wenn ein E-Mail-Versand mit formatierten HTML-Mails verwendet wird. Ich möchte eine Klasse erstellen, die einen HTML-Wrapper und Inhalts-Elemente für strukturierte E-Mails bereithält. Dadurch soll es möglich sein, sehr einfach neue E-Mails für individuellen Code zu generieren. (Wenn z.B. die Plugin-Options aktualisiert werden, etc.)
5. WordPress kommt immer mit Funktionen, die niemand braucht und dann ausgeschaltet werden (z.B. die Emojis). Das ist Code, der das Frontend unnötig aufbläht. Durch fertige Plugin-Optionen soll der Admin entscheiden können, ob solche Codes entfernt werden sollen. 
6. Die Admin-Bar im Frontend nervt, wenn man eingeloggt ist. Ich habe bereits bei ein paar unserer Kunden eine Alternative zu dieser Admin-Bar eingestellt. Ich möchte diese Stile auch für das WP-Plugin-AddOn hinzufügen. Im Backend soll dann ausgewählt werden können, ob man eine Alternative Admin-Bar haben möchte, oder nicht.
7. Was noch gar nicht berücksichtigt wird ist die Kompatibilität mit WPBakery und Gutenberg. Ich versuche die Struktur der Shortcodes zu erstellen, dass bei der Erstellung eines neuen Shortcodes diese beiden Bereiche auch abgedeckt werden können. 
8. Ich habe bereits angefangen eine Datei `bootstrap.js` zu erstellen. Diese soll dazu dienen jQuery nach und nach für unsere Plugins abzulösen. Diese Sammlung soll dynamisch werden - Das bedeutet, dass keine JS-Funktionen geladen werden, wenn diese nicht verwendet werden. Das JavaScript soll lernen nur die Funktionen zu verwenden, die es auch für das aktuelle Projekt benötigt. (Mal schauen, ob ich das schaffe...)
9. Die Verschiedenen Funktionen für die Registrierung, Login, Profil und Passwort-Zurücksetzen sollen als Vorlage zum `WP-Plugin-AddOn` hinzugefügt werden. Dadurch soll es möglich sein, die jeweiligen Masken in nur wenigen Schritten zu erstellen.