#!/bin/bash


# Output Colors
ERROR='\033[0;31m'
WARNING='\033[0;33m'
SUCCESS='\033[0;32m'
FILE='\033[1;34m'
TEXT='\033[0m'


# Get Basedir
BASEDIR=$(pwd)


# Get Plugin Variables from /[PLUGIN]/bin/plugin-data.sh
if [ -f "${BASEDIR}/bin/plugin-data.sh" ]; then
    echo "Read Conf-File from ${FILE}${BASEDIR}/bin/plugin-data.sh${TEXT}"
    . "${BASEDIR}/bin/plugin-data.sh"
else
    echo "${FILE}${BASEDIR}/bin/plugin-data.sh${TEXT}${ERROR} not existing${TEXT}"
    exit 1
fi


# Clear Plugin-File
echo "Clean old JSON-File ..."
printf "" > error.json

# Set Error Message as Variable
ERROR_MESSAGE="<div class='notice notice-error notice-alt'><p><strong>Error:</strong> Your License is not valid or any error occured. Please renew your license or contact <a href='mailto:info@codepalm.de'>info@codepalm.de</a></p></div>"

# Setup Plugin-File
echo "Setup new JSON-File ..."
printf "{

    \"name\": \"$JSON_PLUGIN_NAME\",
    \"version\": \"$JSON_PLUGIN_VERSION\",
	\"download_url\": \"\",

	\"homepage\": \"$JSON_PLUGIN_HOMEPAGE\",
	\"requires\": \"$JSON_PLUGIN_MIN_VERSION\",
	\"tested\": \"$JSON_PLUGIN_MAX_VERSION\",
	\"last_updated\": \"$JSON_PLUGIN_LAST_UPDATE\",
	\"upgrade_notice\": \"$JSON_UPDATE_NOTICE\",

	\"author\": \"$JSON_AUTHOR_NAME\",
	\"author_homepage\": \"$JSON_AUTHOR_URL\",

	\"sections\": {
		\"description\": \"$ERROR_MESSAGE$JSON_PLUGIN_DESCRIPTION\",
		\"installation\": \"$JSON_PLUGIN_INSTALLATION\",
		\"changelog\": \"$JSON_PLUGIN_CHANGELOG\"
	},
	
	\"icons\" : {
		\"1x\": \"$JSON_PLUGIN_ICON_LOW\",
		\"2x\" : \"$JSON_PLUGIN_ICON_HIGH\"
    },

	\"banners\": {
		\"low\": \"$JSON_PLUGIN_BANNER_LOW\",
		\"high\": \"$JSON_PLUGIN_BANNER_HIGH\"
	}

}" >> error.json

if [ $( stat --printf="%s" error.json ) -eq 0 ]; then
	echo "${ERROR}File ${FILE}error.json${ERROR} is empty${TEXT}"
else 
	echo "${SUCCESS}File ${FILE}error.json${SUCCESS} created successfully${TEXT}"
fi