<?php

    namespace CPPluginCore;

    if( !class_exists( '\CPPluginCore\AdminError' ) ) {
        
        class AdminError {

            function __construct( $msg, $err_obj=false ) {
                
                $this->error_output( $msg, $err_obj );

            }

            protected function error_output( $msg, $err_obj=false ) {

                if( $err_obj !== false )
                    $err = $this->get_errorcodes( $err_obj );

                \add_action( 'admin_notices', function() use ( $msg, $err ) {
                    $this->admin_notice__error( $msg, $err );
                });

            }

            protected function admin_notice__error( $message, $error_codes="" ) {

                $class = 'notice notice-error';
                printf( '<div class="%1$s"><p>%2$s</p>%3$s</div>', \esc_attr( $class ), $message, $error_codes ); 

            }

            protected function get_errorcodes( $error_obj, $arr=false ) {

                $error_codes = "";
                if( $arr )
                    $error_codes = array();
                
                foreach( $error_obj->error as $error_wrapper ) {
                    foreach( $error_wrapper->error_data as $error ) {
                        if( $arr ) {
                            $error_codes[] = $error->status;
                        }
                        else {
                            if( !empty( $error_codes ) )
                                $error_codes .= ", ";
                            $error_codes .= $error->status;
                        }
                    }
                }

                if( !empty( $error_codes ) && !$arr )
                    $error_codes = '<p>' . sprintf( 'Error-Codes: %1$s', $error_codes ) . '</p>';
                
                return $error_codes;

            }


            public static function get_error( $type ) {

                switch( $type ) {
                    case 301:
                        // Update Checker could not been loaded
                        $msg = __(
                            'Update-Checker couldn\'t be loaded',
                            'cp-plugin-core'
                        );
                        break;
                    case 301:
                        // Update-Host is not defined
                        $msg = __(
                            'Update-Host is not defined',
                            'cp-plugin-core'
                        );
                        break;
                    case 999:
                        // Update-Host is not defined
                        $msg = __(
                            'Everything\'s ok',
                            'cp-plugin-core'
                        );
                        break;
                    default:

                        // Load Individual Error-Codes
                        $msg = \apply_filters( 'custom_error_codes', $msg, $type );
                        
                        // Undefined Error
                        if( empty( $msg ) ) {
                            $msg = \__(
                                'An undefined Error happend in CF7 Event-Tracker',
                                'cp-plugin-core'
                            );
                        }
                        
                        break;
                }

                new AdminError( $msg );

                /*
                    1xx: 
                        101: 

                    2xx: 
                        201: 

                    3xx: Update
                        301: Update-Klasse konnte nicht geladen werden
                        302: Update-Host wurde nicht definiert
                */

            }

        }
    }

?>
