<?php

    namespace CPPluginCore;

    if( !class_exists( '\CPPluginCore\Options' ) ) {
        
        class Options {

            protected $page_id;
            protected $parent_id;
            protected $capabilities;

            function __construct( $page_id, $parent_id=false, $capabilities="administrator" ) {
                
                $this->page_id = $page_id;

                if( $parent_id === false ) {

                    $this->parent_id = $page_id;

                }
                else {

                    $this->parent_id = $parent_id;

                }

                $this->capabilities = $capabilities;

            }

            public function register_hooks( $options_type, $parent_title, $menu_title, $sub=false, $icon_url="", $position=90 ) {

                $this->add_page( $sub, $parent_title, $menu_title, $icon_url, $position );
                $this->options_init( $options_type );

                $this->parse_post();

            }

            protected function add_page( $sub, $parent_title="Einstellungen", $menu_title="Einstellungen", $icon_url="", $position=90 ) {
    
                if( $sub === false ) {

                    \add_menu_page(
                        $parent_title,
                        $parent_title,
                        $this->capabilities,
                        $this->page_id,
                        array( $this, 'page_callback' ),
                        $icon_url,
                        $position
                    );

                    \add_submenu_page(
                        $this->parent_id,
                        $menu_title, 
                        $menu_title,
                        $this->capabilities,
                        $this->page_id,
                        array( $this, 'page_callback' ),
                        $position
                    );
                    
                }
                else {

                    \add_submenu_page(
                        $this->parent_id,
                        $menu_title,
                        $menu_title,
                        $this->capabilities,
                        $this->page_id,
                        array( $this, 'page_callback' ),
                        $position
                    );

                }

            }

            protected function parse_post() {

                // $_POST Algorithm

            }

            public function page_callback() {

                echo $this->resolve_page_parts( $this->get_page_structure() );

            }

            protected function options_init( $type="plugin" ) {

                if( empty( $type ) )
                    return false;

                \register_setting(
                    'cp_plugin_options',
                    'cp_plugin_' . $type . '_options',
                    array( $this, 'validate_options' )
                );

            }

            public function validate_options( $input ) {

                return $input;

            }


            protected function get_page_structure() {

                ob_start();
                ?>
                    <div id="plugin_page">
                        <div id="plugin_header">
                            %HEADER%
                        </div>
                        <div id="plugin_body">
                            <div id="plugin_content">
                                %CONTENT%
                            </div>
                            <div id="plugin_sidebar">
                                %SIDEBAR%
                            </div>
                        </div>
                        <div id="pugin_footer">
                            %FOOTER%
                        </div>
                    </div>
                <?php
                $result = ob_get_clean();

                $result = apply_filters( 'cpc_options_page_structure', $result );

                return $result;

            }

            protected function get_content_wrapper( $content ) {

                $custom_class = array();
                $custom_class = apply_filters( 'cpc_content_wrapper_custom_class', $custom_class );

                if( is_array( $custom_class ) && !empty( $custom_class ) ) {
                    $custom_class = join( " ", $custom_class );
                }
                else {
                    $custom_class = "";
                }

                ob_start();
                ?>
                    <div class="content_wrapper <?php echo $custom_class; ?>">
                        <?php echo $content; ?>
                    </div>
                <?php
                return ob_get_clean();

            }

            protected function get_header() {
                
                ob_start();
                ?>
                    <h1>Header</h1>
                <?php
                return ob_get_clean();

            }

            protected function get_footer() {

                ob_start();
                ?>
                    <p>Footer</p>
                <?php
                return ob_get_clean();

            }

            protected function get_content() {

                ob_start();
                ?>
                    <p>Content</p>
                <?php
                return ob_get_clean();

            }

            protected function get_sidebar() {

                ob_start();
                ?>
                    <p>Sidebar</p>
                <?php
                return ob_get_clean();

            }

            protected function resolve_page_parts( $structure ) {

                $replacements = array(
                    '%HEADER%'  => $this->get_header(),
                    '%FOOTER%'  => $this->get_footer(),
                    '%SIDEBAR%'  => $this->get_sidebar(),
                    '%CONTENT%'  => $this->get_content()
                );

                $replacements = apply_filters( 'cpc_option_page_parts', $replacements );

                foreach( $replacements as $needle => $replacement ) {

                    $structure = str_replace( $needle, $this->get_content_wrapper( $replacement ), $structure );

                }
                
                return $structure;

            }

        }

    }

?>