<?php

    namespace CPPluginCore;

    if( !class_exists( '\CPPluginCore\Loader' ) ) {

        abstract class Loader {

            private $plugin_path;
            private $plugin_url;

            function __construct( $plugin_path="", $plugin_url="" ) {

                $this->plugin_path = $plugin_path;
                $this->plugin_url = $plugin_url;
                $this->load_dependecies();
                
            }

            public function init_loader() {

                \add_action( 'init', array( $this, 'loadFiles' ) );

            }

            protected function load_dependecies() {

                if( !class_exists( File::class ) ) {

                    $file_class_path = $this->plugin_path . 'vendor/codepalm/wp-plugin-core/inc/loader/File.php';
                    if( file_exists( $file_class_path ) )
                        require( $file_class_path );
                    
                }

            }

            public function loadFiles() {

                if( \is_admin() ) {

                    // Set Site-Specific Includes for Backend
                    $current_page = -1;
                    if( array_key_exists( 'page', $_GET ) )
                        $current_page = $_GET[ 'page' ];
                    $this->get_loader_files( $current_page, $this->get_backend_files() );
        
                }
                else {

                    // Set Site-Specific Includes for Frontend
                    $current_page = -1;
                    if( array_key_exists( 'page', $_GET ) )
                        $current_page = $_GET[ 'page' ];
                    $this->get_loader_files( $current_page, $this->get_frontend_files() );
        
                }

            }

            public function get_loader_files( $page, $files ) {

                foreach( $files as $file ) {
        
                    if( $file->loadFile( $page ) !== false )
                        $this->load_files( $file, $page );
        
                }

            }

            public function load_files( $file, $page ) {

                if( $file->fileIsRequired() ) {
                    require_once $file->loadFile( $page );
                }
                else {
                    include_once $file->loadFile( $page );
                }
                $file->triggerCallback();

            }

            public function get_backend_files() {
                
                $files = array(
                    'high'		=> array(
                        'admin_error'       => new File(
                            $this->plugin_path . 'vendor/codepalm/wp-plugin-core/inc/globals/AdminError.php',
                            -1,
                            false,
                            null
                        ),
                        'credentials'       => new File( 
                            $this->plugin_path . 'vendor/codepalm/wp-plugin-core/inc/globals/Credentials.php',
                            -1,
                            false,
                            null
                        ),
                        'include'    => new File(
                            $this->plugin_path . 'vendor/codepalm/wp-plugin-core/inc/globals/IncludeScripts.php',
                            -1,
                            true,
                            function() {

                                $include = new IncludeScripts();
                                $include->register_hooks( $this->plugin_url );

                            }
                        ),
                        'options'    => new File(
                            $this->plugin_path . 'vendor/codepalm/wp-plugin-core/inc/globals/backend/Options.php',
                            -1,
                            true,
                            null
                        )
                    ),
                    'low'		=> array(
                        
                    )
                );
                
                $result_files = array();
                
                $result_files = array_merge( $result_files, $files[ 'high' ] );					            // Default High
                $result_files = array_merge( $result_files, $this->get_custom_backend_files( 'high' ) );	// Custom High
                $result_files = array_merge( $result_files, $files[ 'low' ] );						        // Default Low
                $result_files = array_merge( $result_files, $this->get_custom_backend_files( 'low' ) );	    // Custom Low

                return $result_files;
        
            }

            public function get_frontend_files() {

                $files = array(
                    'high'		=> array(
                        'shortcodes'    => new File(
                            $this->plugin_path . 'vendor/codepalm/wp-plugin-core/inc/globals/Shortcode.php',
                            -1,
                            true,
                            null
                        ),
                        'include'    => new File(
                            $this->plugin_path . 'vendor/codepalm/wp-plugin-core/inc/globals/IncludeScripts.php',
                            -1,
                            true,
                            function() {

                                $include = new IncludeScripts();
                                $include->register_hooks();

                            }
                        )
                    ),
                    'low'		=> array(
                        
                    )
                );

                $result_files = array();
                
                $result_files = array_merge( $result_files, $files[ 'high' ] );					            // Default High
                $result_files = array_merge( $result_files, $this->get_custom_frontend_files( 'high' ) );	// Custom High
                $result_files = array_merge( $result_files, $files[ 'low' ] );						        // Default Low
                $result_files = array_merge( $result_files, $this->get_custom_frontend_files( 'low' ) );	// Custom Low

                return $result_files;
        
            }

            abstract protected function get_custom_backend_files( $priority );

            abstract protected function get_custom_frontend_files( $priority );

        }

    }

?>